@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: BibleComboBoxModelSet.java 1170 2006-10-19 21:49:36Z dmsmith $
+ * ID: $Id: BibleComboBoxModelSet.java 1890 2008-07-09 12:15:15Z dmsmith $
  */
 package org.crosswire.bibledesktop.book;
 
@@ -25,13 +25,18 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.ItemEvent;
 import java.awt.event.ItemListener;
+import java.io.IOException;
+import java.io.ObjectInputStream;
+import java.io.Serializable;
 
 import javax.swing.JComboBox;
 import javax.swing.event.EventListenerList;
 
+import org.crosswire.common.swing.NumberCellRenderer;
 import org.crosswire.jsword.passage.NoSuchVerseException;
 import org.crosswire.jsword.passage.Verse;
 import org.crosswire.jsword.versification.BibleInfo;
+import org.crosswire.jsword.versification.BookName;
 
 /**
  * A set of correctly constructed and linked BibleComboBoxModels.
@@ -39,14 +44,26 @@ import org.crosswire.jsword.versification.BibleInfo;
  * @see gnu.gpl.License for license details.
  *      The copyright to this program is held by it's authors.
  * @author Joe Walker [joe at eireneh dot com]
+ * @author DM Smith [dmsmith555 at yahoo dot com]
  */
-public class BibleComboBoxModelSet
+public class BibleComboBoxModelSet implements Serializable
 {
     public BibleComboBoxModelSet(JComboBox books, JComboBox chapters, JComboBox verses)
     {
+        listeners = new EventListenerList();
+        cil = new CustomItemListener();
+
+        mdlBook = new BibleComboBoxModel(this, BibleComboBoxModel.LEVEL_BOOK);
         setBookComboBox(books);
+
+        mdlChapter = new BibleComboBoxModel(this, BibleComboBoxModel.LEVEL_CHAPTER);
         setChapterComboBox(chapters);
-        setVerseComboBox(verses);
+
+        if (verses != null)
+        {
+            mdlVerse = new BibleComboBoxModel(this, BibleComboBoxModel.LEVEL_VERSE);
+            setVerseComboBox(verses);
+        }
     }
 
     /**
@@ -58,6 +75,16 @@ public class BibleComboBoxModelSet
 
         cboBook.setModel(mdlBook);
         cboBook.addItemListener(cil);
+        cboBook.setRenderer(new BibleNameCellRenderer(true));
+
+        try
+        {
+            cboBook.setToolTipText(BibleInfo.getLongBookName(verse.getBook()));
+        }
+        catch (NoSuchVerseException ex)
+        {
+            assert false : ex;
+        }
     }
 
     /**
@@ -71,6 +98,7 @@ public class BibleComboBoxModelSet
         // There are over 100 chapters in some books
         cboChapter.setPrototypeDisplayValue(new Integer(999));
         cboChapter.addItemListener(cil);
+        cboChapter.setRenderer(new NumberCellRenderer());
     }
 
     /**
@@ -82,8 +110,9 @@ public class BibleComboBoxModelSet
 
         cboVerse.setModel(mdlVerse);
         // There are over 100 verses in some chapters
-        cboChapter.setPrototypeDisplayValue(new Integer(999));
+        cboVerse.setPrototypeDisplayValue(new Integer(999));
         cboVerse.addItemListener(cil);
+        cboVerse.setRenderer(new NumberCellRenderer());
     }
 
     /**
@@ -94,15 +123,6 @@ public class BibleComboBoxModelSet
         return verse;
     }
 
-    /**
-     * Sets the verse.
-     * @param newverse The verse to set
-     */
-    protected void setViewedVerse(Verse newverse)
-    {
-        setVerse(newverse);
-    }
-
     /**
      * Set the combo-boxes to a new verse
      */
@@ -118,10 +138,11 @@ public class BibleComboBoxModelSet
             Verse oldverse = verse;
             verse = newverse;
             int bookval = newverse.getBook();
-            String book = BibleInfo.getLongBookName(bookval);
-            if (oldverse.getBook() != bookval || !cboBook.getSelectedItem().equals(book))
+            BookName bookName = BibleInfo.getBookName(bookval);
+            if (oldverse.getBook() != bookval || !cboBook.getSelectedItem().equals(bookName))
             {
-                cboBook.setSelectedItem(book);
+                cboBook.setSelectedItem(bookName);
+                cboBook.setToolTipText(bookName.getLongName());
             }
 
             int chapterval = newverse.getChapter();
@@ -131,11 +152,14 @@ public class BibleComboBoxModelSet
                 cboChapter.setSelectedItem(chapternum);
             }
 
-            int verseval = newverse.getVerse();
-            Integer versenum = new Integer(verseval);
-            if (oldverse.getVerse() != verseval || !cboVerse.getSelectedItem().equals(versenum))
+            if (cboVerse != null)
             {
-                cboVerse.setSelectedItem(versenum);
+                int verseval = newverse.getVerse();
+                Integer versenum = new Integer(verseval);
+                if (oldverse.getVerse() != verseval || !cboVerse.getSelectedItem().equals(versenum))
+                {
+                    cboVerse.setSelectedItem(versenum);
+                }
             }
 
             fireContentsChanged();
@@ -146,19 +170,6 @@ public class BibleComboBoxModelSet
         }
     }
 
-    private Verse verse = Verse.DEFAULT;
-
-    protected JComboBox cboBook;
-    protected JComboBox cboChapter;
-    private JComboBox cboVerse;
-
-    protected BibleComboBoxModel mdlBook = new BibleComboBoxModel(this, BibleComboBoxModel.LEVEL_BOOK);
-    protected BibleComboBoxModel mdlChapter = new BibleComboBoxModel(this, BibleComboBoxModel.LEVEL_CHAPTER);
-    protected BibleComboBoxModel mdlVerse = new BibleComboBoxModel(this, BibleComboBoxModel.LEVEL_VERSE);
-
-    protected EventListenerList listeners = new EventListenerList();
-    private ItemListener cil = new CustomItemListener();
-
     /**
      * Add a listener to the list that's notified each time a change
      * to the data model occurs.
@@ -203,11 +214,25 @@ public class BibleComboBoxModelSet
         }
     }
 
+    /**
+     * Serialization support.
+     * 
+     * @param is
+     * @throws IOException
+     * @throws ClassNotFoundException
+     */
+    private void readObject(ObjectInputStream is) throws IOException, ClassNotFoundException
+    {
+        cil = new CustomItemListener();
+        is.defaultReadObject();
+    }
+
     /**
      * For when a selection is made
      */
     final class CustomItemListener implements ItemListener
     {
+
         public void itemStateChanged(ItemEvent ev)
         {
             if (ev.getStateChange() == ItemEvent.SELECTED)
@@ -220,11 +245,29 @@ public class BibleComboBoxModelSet
                     mdlChapter.fireContentsChanged(this, 0, mdlChapter.getSize());
                 }
 
-                if (source.equals(cboBook) || source.equals(cboChapter))
+                if (mdlVerse != null && (source.equals(cboBook) || source.equals(cboChapter)))
                 {
                     mdlVerse.fireContentsChanged(this, 0, mdlVerse.getSize());
                 }
             }
         }
     }
+
+    private Verse verse = Verse.DEFAULT;
+
+    protected JComboBox cboBook;
+    protected JComboBox cboChapter;
+    private JComboBox cboVerse;
+
+    protected BibleComboBoxModel mdlBook;
+    protected BibleComboBoxModel mdlChapter;
+    protected BibleComboBoxModel mdlVerse;
+
+    protected EventListenerList listeners;
+    private transient ItemListener cil;
+
+    /**
+     * Serialization ID
+     */
+    private static final long serialVersionUID = 5365220628525297473L;
 }
