@@ -14,13 +14,14 @@
  *      59 Temple Place - Suite 330
  *      Boston, MA 02111-1307, USA
  *
- * Copyright: 2005
+ * Copyright: 2007
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: DisplaySelectPane.java 1068 2006-04-08 02:20:41Z dmsmith $
+ * ID: $Id: DisplaySelectPane.java 1887 2008-07-08 03:15:12Z dmsmith $
  */
 package org.crosswire.bibledesktop.book;
 
+import java.awt.FlowLayout;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
 import java.awt.Insets;
@@ -28,13 +29,11 @@ import java.awt.SystemColor;
 import java.awt.Toolkit;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import java.awt.event.ItemEvent;
-import java.awt.event.ItemListener;
 import java.awt.event.KeyAdapter;
 import java.awt.event.KeyEvent;
+import java.io.IOException;
+import java.io.ObjectInputStream;
 
-import javax.swing.BorderFactory;
-import javax.swing.ImageIcon;
 import javax.swing.JButton;
 import javax.swing.JComboBox;
 import javax.swing.JLabel;
@@ -47,13 +46,17 @@ import org.crosswire.bibledesktop.book.install.IndexResolver;
 import org.crosswire.bibledesktop.passage.KeyChangeEvent;
 import org.crosswire.bibledesktop.passage.KeyChangeListener;
 import org.crosswire.common.swing.ActionFactory;
+import org.crosswire.common.swing.CWOptionPane;
 import org.crosswire.common.swing.GuiUtil;
 import org.crosswire.common.swing.QuickHelpDialog;
 import org.crosswire.common.swing.desktop.event.TitleChangedEvent;
 import org.crosswire.common.swing.desktop.event.TitleChangedListener;
 import org.crosswire.common.util.Reporter;
 import org.crosswire.jsword.book.Book;
+import org.crosswire.jsword.book.BookComparators;
+import org.crosswire.jsword.book.BookException;
 import org.crosswire.jsword.book.BookFilters;
+import org.crosswire.jsword.book.BookProvider;
 import org.crosswire.jsword.index.IndexStatus;
 import org.crosswire.jsword.index.IndexStatusEvent;
 import org.crosswire.jsword.index.IndexStatusListener;
@@ -61,9 +64,13 @@ import org.crosswire.jsword.index.search.DefaultSearchModifier;
 import org.crosswire.jsword.index.search.DefaultSearchRequest;
 import org.crosswire.jsword.passage.Key;
 import org.crosswire.jsword.passage.NoSuchKeyException;
+import org.crosswire.jsword.passage.NoSuchVerseException;
 import org.crosswire.jsword.passage.PassageTally;
 import org.crosswire.jsword.passage.RestrictionType;
 import org.crosswire.jsword.passage.RocketPassage;
+import org.crosswire.jsword.passage.Verse;
+import org.crosswire.jsword.passage.VerseRange;
+import org.crosswire.jsword.versification.BibleInfo;
 
 /**
  * Passage Selection area.
@@ -71,8 +78,9 @@ import org.crosswire.jsword.passage.RocketPassage;
  * @see gnu.gpl.License for license details.
  *      The copyright to this program is held by it's authors.
  * @author Joe Walker [joe at eireneh dot com]
+ * @author DM Smith [dmsmith555 at yahoo dot com]
  */
-public class DisplaySelectPane extends JPanel implements KeyChangeListener
+public class DisplaySelectPane extends JPanel implements KeyChangeListener, BookSelectListener, BookProvider
 {
     /**
      * General constructor
@@ -95,16 +103,22 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
 
         actions = new ActionFactory(DisplaySelectPane.class, this);
 
-        // search() and version() rely on this returning only Bibles
-        mdlBible = new BooksComboBoxModel(BookFilters.getBibles());
-        JComboBox cboBible = new JComboBox(mdlBible);
-        cboBible.setPrototypeDisplayValue(" "); //$NON-NLS-1$
-        selected = mdlBible.getSelectedBook();
-        if (selected != null)
+        isl = new IndexStatusListener()
         {
-            selected.addIndexStatusListener(isl);
-            cboBible.setToolTipText(selected.toString());
-            key = selected.createEmptyKeyList();
+            public void statusChanged(IndexStatusEvent ev)
+            {
+                enableComponents();
+            }
+        };
+
+        // search() and version() rely on this returning only Books indexed by verses
+        biblePicker = new ParallelBookPicker(BookFilters.getBibles(), BookComparators.getInitialComparator());
+        biblePicker.addBookListener(this);
+        selected = biblePicker.getBooks();
+        if (selected != null && selected.length > 0)
+        {
+            selected[0].addIndexStatusListener(isl);
+            key = selected[0].createEmptyKeyList();
         }
         else
         {
@@ -113,31 +127,39 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
             // But here we don't have a book yet.
             key = new RocketPassage();
         }
-        cboBible.setRenderer(new BookListCellRenderer());
-        cboBible.addItemListener(new ItemListener()
+
+        JComboBox cboBooks = new JComboBox();
+        JComboBox cboChaps = new JComboBox();
+        quickSet = new BibleComboBoxModelSet(cboBooks, cboChaps, null);
+        quickSet.addActionListener(new ActionListener()
         {
-            /* (non-Javadoc)
-             * @see java.awt.event.ItemListener#itemStateChanged(java.awt.event.ItemEvent)
-             */
-            public void itemStateChanged(ItemEvent ev)
+            public void actionPerformed(ActionEvent ev)
             {
-                if (ev.getStateChange() == ItemEvent.SELECTED)
+                BibleComboBoxModelSet set = (BibleComboBoxModelSet) ev.getSource();
+                Verse start = set.getVerse();
+                int book = start.getBook();
+                int chapter = start.getChapter();
+                try
                 {
-                    changeVersion();
-                    JComboBox combo = (JComboBox) ev.getSource();
-                    combo.setToolTipText(combo.getSelectedItem().toString());
+                    VerseRange range = new VerseRange(start, new Verse(book, chapter, BibleInfo.versesInChapter(book, chapter)));
+                    txtSearch.setText(""); //$NON-NLS-1$
+                    txtKey.setText(range.getName());
+                    doGoPassage();
+                }
+                catch (NoSuchVerseException ex)
+                {
+                    assert false : ex;
                 }
             }
         });
-        cboBible.addActionListener(new SelectedActionListener());
-        JLabel lblBible = actions.createJLabel(BIBLE);
-        lblBible.setLabelFor(cboBible);
 
-        /* LATER(JOE)
-        JButton btnMenu = new JButton();
-        btnMenu.setIcon(ICON_MENU);
-        btnMenu.setBorderPainted(false);
-        */
+        JPanel quickPicker = new JPanel();
+        quickPicker.setLayout(new FlowLayout());
+        quickPicker.add(cboBooks);
+        quickPicker.add(cboChaps);
+
+        JLabel lblBible = actions.createJLabel(BIBLE);
+        lblBible.setLabelFor(biblePicker);
 
         JLabel lblKey = actions.createJLabel(VIEW_LABEL);
         txtKey = new JTextField();
@@ -157,53 +179,78 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
             }
         });
         btnKey = new JButton(actions.getAction(MORE));
-        btnKey.setIcon(ICON_SELECT);
-        btnKey.setBorder(BorderFactory.createEmptyBorder(3, 5, 3, 5));
         btnKeyGo = new JButton(actions.getAction(GO_PASSAGE));
-        btnKeyGo.setBorder(BorderFactory.createEmptyBorder(4, 5, 4, 5));
 
         txtSearch = new JTextField();
         txtSearch.setAction(actions.getAction(SEARCH_FIELD));
         JLabel lblSearch = actions.createJLabel(SEARCH_LABEL);
         lblSearch.setLabelFor(txtSearch);
         btnSearch = new JButton(actions.getAction(GO_SEARCH));
-        btnSearch.setBorder(BorderFactory.createEmptyBorder(4, 5, 4, 5));
 
-        JButton btnHelp = new JButton(actions.getAction(HELP));
-        btnHelp.setBorder(BorderFactory.createEmptyBorder(2, 5, 2, 5));
-        btnHelp.setText(null);
+        JButton btnHelp = actions.createActionIcon(HELP);
         dlgHelp = new QuickHelpDialog(GuiUtil.getFrame(this), Msg.HELP_TITLE.toString(), Msg.HELP_TEXT.toString());
 
         btnAdvanced = new JButton(actions.getAction(ADVANCED));
-        btnAdvanced.setBorder(BorderFactory.createEmptyBorder(3, 5, 3, 5));
         btnIndex = new JButton(actions.getAction(INDEX));
-        btnIndex.setBorder(BorderFactory.createEmptyBorder(3, 15, 3, 15));
 
         this.setLayout(new GridBagLayout());
-        this.add(lblBible,    new GridBagConstraints(0, 0, 2, 1, 0.0, 0.0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(0, 0, 0, 5), 0, 0));
-        this.add(cboBible,    new GridBagConstraints(2, 0, 4, 1, 1.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));
+        this.add(lblBible,    new GridBagConstraints(0, 0, 2, 1, 0.0, 0.0, GridBagConstraints.LINE_END, GridBagConstraints.VERTICAL, new Insets(0, 0, 0, 5), 0, 0));
+        this.add(biblePicker, new GridBagConstraints(2, 0, 2, 1, 1.0, 0.0, GridBagConstraints.LINE_START, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));
+        this.add(quickPicker, new GridBagConstraints(4, 0, 2, 1, 0.0, 0.0, GridBagConstraints.LINE_END, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
 
-        this.add(lblKey,      new GridBagConstraints(0, 1, 2, 1, 0.0, 0.0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(0, 0, 0, 5), 0, 0));
+        this.add(lblKey,      new GridBagConstraints(0, 1, 2, 1, 0.0, 0.0, GridBagConstraints.LINE_END, GridBagConstraints.NONE, new Insets(0, 0, 0, 5), 0, 0));
         this.add(txtKey,      new GridBagConstraints(2, 1, 2, 1, 1.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(2, 0, 1, 2), 0, 0));
-        this.add(btnKey,      new GridBagConstraints(4, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(2, 0, 2, 2), 0, 0));
-        this.add(btnKeyGo,    new GridBagConstraints(5, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));
+        this.add(btnKeyGo,    new GridBagConstraints(4, 1, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));
+        this.add(btnKey,      new GridBagConstraints(5, 1, 1, 1, 0.0, 0.0, GridBagConstraints.LINE_END, GridBagConstraints.HORIZONTAL, new Insets(2, 0, 2, 2), 0, 0));
 
-        this.add(btnHelp,     new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
-        this.add(lblSearch,   new GridBagConstraints(1, 2, 1, 1, 0.0, 0.0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(0, 0, 0, 5), 0, 0));
-        this.add(btnIndex,    new GridBagConstraints(2, 2, 1, 1, 1.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(2, 0, 2, 2), 0, 0));
+        this.add(btnHelp,     new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0, GridBagConstraints.LINE_START, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
+        this.add(lblSearch,   new GridBagConstraints(1, 2, 1, 1, 0.0, 0.0, GridBagConstraints.LINE_END, GridBagConstraints.NONE, new Insets(0, 0, 0, 5), 0, 0));
+        this.add(btnIndex,    new GridBagConstraints(2, 2, 1, 1, 1.0, 0.0, GridBagConstraints.LINE_START, GridBagConstraints.NONE, new Insets(2, 0, 2, 2), 0, 0));
         this.add(txtSearch,   new GridBagConstraints(2, 2, 1, 1, 1.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(2, 0, 3, 2), 0, 0));
-        this.add(btnAdvanced, new GridBagConstraints(4, 2, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(2, 0, 2, 2), 0, 0));
-        this.add(btnSearch,   new GridBagConstraints(5, 2, 1, 1, 0.0, 0.0, GridBagConstraints.EAST, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));
+        this.add(btnSearch,   new GridBagConstraints(4, 2, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), 0, 0));
+        this.add(btnAdvanced, new GridBagConstraints(5, 2, 1, 1, 0.0, 0.0, GridBagConstraints.LINE_END, GridBagConstraints.HORIZONTAL, new Insets(2, 0, 2, 2), 0, 0));
 
         enableComponents();
+        GuiUtil.applyDefaultOrientation(this);
+
     }
 
     /**
-     * What is the currently selected Book?
+     * During view creation, allow firing off an event to display the initial book/chapter.
+     * This is copied from quickSet.addActionListener().
      */
-    public Book getBook()
+    public void doInitialTextDisplay()
     {
-        return selected;
+        Verse start = quickSet.getVerse();
+        int book = start.getBook();
+        int chapter = start.getChapter();
+        try
+        {
+            VerseRange range = new VerseRange(start, new Verse(book, chapter, BibleInfo.versesInChapter(book, chapter)));
+            txtSearch.setText(""); //$NON-NLS-1$
+            txtKey.setText(range.getName());
+            doGoPassage();
+        }
+        catch (NoSuchVerseException ex)
+        {
+            assert false : ex;
+        }
+    }
+
+    /**
+     * What are the currently selected Books?
+     */
+    public Book[] getBooks()
+    {
+        return (Book[]) selected.clone();
+    }
+
+    /**
+     * What is the first currently selected book?
+     */
+    public Book getFirstBook()
+    {
+        return selected != null && selected.length > 0 ? selected[0] : null;
     }
 
     /**
@@ -211,7 +258,7 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
      */
     public void clear()
     {
-        setKey(selected == null ? new RocketPassage() : selected.createEmptyKeyList());
+        setKey(selected == null || selected.length == 0 ? new RocketPassage() : selected[0].createEmptyKeyList());
         setTitle(CLEAR);
     }
 
@@ -265,7 +312,7 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
      */
     public void doSearchAction()
     {
-        if (selected == null)
+        if (selected == null || selected.length == 0)
         {
             noBookInstalled();
             return;
@@ -284,12 +331,12 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
             DefaultSearchModifier modifier = new DefaultSearchModifier();
             modifier.setRanked(rank);
 
-            Key results = selected.find(new DefaultSearchRequest(param, modifier));
-            int total = results.getChildCount();
+            Key results = selected[0].find(new DefaultSearchRequest(param, modifier));
+            int total = results.getCardinality();
             int partial = total;
 
-            // we get PassageTallys for rank searches
-            if (results instanceof PassageTally || rank)
+            // we should get PassageTallys for rank searches
+            if (results instanceof PassageTally)
             {
                 PassageTally tally = (PassageTally) results;
                 tally.setOrdering(PassageTally.ORDER_TALLY);
@@ -319,7 +366,7 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
                 setKey(results);
             }
         }
-        catch (Exception ex)
+        catch (BookException ex)
         {
             Reporter.informUser(this, ex);
         }
@@ -334,6 +381,7 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
         if (reply != null)
         {
             txtSearch.setText(reply);
+            doSearchAction();
         }
     }
 
@@ -360,13 +408,13 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
      */
     public void doIndex()
     {
-        if (selected == null)
+        if (selected == null || selected.length == 0)
         {
             noBookInstalled();
             return;
         }
 
-        IndexResolver.scheduleIndex(selected, this);
+        IndexResolver.scheduleIndex(selected[0], this);
         enableComponents();
     }
 
@@ -375,13 +423,13 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
      */
     private void updateDisplay()
     {
-        if (selected == null)
+        if (selected == null || selected.length == 0)
         {
             noBookInstalled();
             return;
         }
 
-        fireCommandMade(new DisplaySelectEvent(this, key, selected));
+        fireCommandMade(new DisplaySelectEvent(this, key));
     }
 
     /**
@@ -392,17 +440,24 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
         return title;
     }
 
+    /**
+     * @return the picker
+     */
+    public ParallelBookPicker getBiblePicker()
+    {
+        return biblePicker;
+    }
+
     public void setKey(String newKey)
     {
-        if (selected == null)
+        if (selected == null || selected.length == 0)
         {
-            noBookInstalled();
             return;
         }
 
         try
         {
-            setKey(selected.getKey(newKey));
+            setKey(selected[0].getKey(newKey));
         }
         catch (NoSuchKeyException e)
         {
@@ -416,7 +471,7 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
         {
             if (!key.isEmpty())
             {
-                key = selected.createEmptyKeyList();
+                key = selected[0].createEmptyKeyList();
                 txtKey.setText(""); //$NON-NLS-1$
                 txtSearch.setText(""); //$NON-NLS-1$
 
@@ -438,28 +493,6 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
         }
     }
 
-    /**
-     * Sets the default name
-     */
-//    public void setTitle(String title)
-//    {
-//        this.title = title;
-//    }
-
-//    /**
-//     * Sets the default name
-//     */
-//    public void setText(String text)
-//    {
-//        String currentText = txtKey.getText();
-//        if (!currentText.equals(text))
-//        {
-//            txtKey.setText(text);
-//            setTitle(text);
-//            updateDisplay();
-//        }
-//    }
-//
     /**
      * Gets the number of verses that should be shown when a search result is
      * ranked. A value of 0 means show all.
@@ -511,32 +544,6 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
         maxNumRankedVerses = count;
     }
 
-    /**
-     * Someone changed the version combo
-     */
-    protected void changeVersion()
-    {
-        Book newSelected = mdlBible.getSelectedBook();
-
-        if (selected != null && selected != newSelected)
-        {
-            selected.removeIndexStatusListener(isl);
-            newSelected.addIndexStatusListener(isl);
-        }
-
-        selected = newSelected;
-
-        enableComponents();
-
-        if (selected == null)
-        {
-            noBookInstalled();
-            return;
-        }
-
-        fireVersionChanged(new DisplaySelectEvent(this, key, selected));
-    }
-
     private void setTitle(int newMode)
     {
         mode = newMode;
@@ -564,34 +571,23 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
         }
     }
 
-    /**
-     * Keep the selection up to date with indexing.
-     */
-    private IndexStatusListener isl = new IndexStatusListener()
-    {
-        public void statusChanged(IndexStatusEvent ev)
-        {
-            enableComponents();
-        }
-    };
-
     /**
      * Display a dialog indicating that no Bible is installed.
      */
     private void noBookInstalled()
     {
         String noBible = Msg.NO_INSTALLED_BIBLE.toString();
-        JOptionPane.showMessageDialog(this, noBible, noBible, JOptionPane.WARNING_MESSAGE);
+        CWOptionPane.showMessageDialog(this, noBible, noBible, JOptionPane.WARNING_MESSAGE);
     }
 
     /**
      * Ensure that the right components are enabled
      */
-    protected void enableComponents()
+    /*private*/ final void enableComponents()
     {
-        boolean readable = selected != null;
-        boolean searchable = readable && selected.getIndexStatus().equals(IndexStatus.DONE);
-        boolean indexable = readable && selected.getIndexStatus().equals(IndexStatus.UNDONE);
+        boolean readable = selected != null && selected.length > 0;
+        boolean searchable = readable && selected[0].getIndexStatus().equals(IndexStatus.DONE);
+        boolean indexable = readable && selected[0].getIndexStatus().equals(IndexStatus.UNDONE);
 
         txtSearch.setEnabled(searchable);
         txtSearch.setBackground(searchable ? SystemColor.text : SystemColor.control);
@@ -609,7 +605,7 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
     /**
      * Someone clicked the "..." button
      */
-    protected void showSelectDialog()
+    /*private*/ final void showSelectDialog()
     {
         if (dlgSelect == null)
         {
@@ -624,6 +620,35 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
         }
     }
 
+    /* (non-Javadoc)
+     * @see org.crosswire.bibledesktop.book.BookSelectListener#booksChosen(org.crosswire.bibledesktop.book.BookSelectEvent)
+     */
+    public void booksChosen(BookSelectEvent ev)
+    {
+        Book[] books = ev.getBookProvider().getBooks();
+        assert books.length > 0;
+
+        Book newSelected = ev.getBookProvider().getFirstBook();
+
+        if (selected.length > 0 && selected[0] != newSelected)
+        {
+            selected[0].removeIndexStatusListener(isl);
+            newSelected.addIndexStatusListener(isl);
+        }
+
+        selected = books;
+
+        enableComponents();
+
+        if (selected == null || selected.length == 0)
+        {
+            noBookInstalled();
+            return;
+        }
+
+        fireVersionChanged(new DisplaySelectEvent(this, key));
+    }
+
     /* (non-Javadoc)
      * @see org.crosswire.bibledesktop.book.KeyChangeListener#keyChanged(org.crosswire.bibledesktop.book.KeyChangeEvent)
      */
@@ -723,21 +748,29 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
     }
 
     /**
-     *
+     * Serialization support.
+     * 
+     * @param is
+     * @throws IOException
+     * @throws ClassNotFoundException
      */
-    private static final class SelectedActionListener implements ActionListener
+    private void readObject(ObjectInputStream is) throws IOException, ClassNotFoundException
     {
-        /* (non-Javadoc)
-         * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
-         */
-        public void actionPerformed(ActionEvent e)
+        // We don't serialize views
+        selected = null;
+
+        listeners = new EventListenerList();
+
+        actions = new ActionFactory(DisplaySelectPane.class, this);
+
+        isl = new IndexStatusListener()
         {
-            JComboBox cbo = (JComboBox) e.getSource();
-            if (cbo.getSelectedIndex() == -1 && cbo.getItemCount() > 0)
+            public void statusChanged(IndexStatusEvent ev)
             {
-                cbo.setSelectedIndex(0);
+                enableComponents();
             }
-        }
+        };
+        is.defaultReadObject();
     }
 
     // For the Passage card
@@ -753,9 +786,10 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
     private static final String BIBLE = "Bible"; //$NON-NLS-1$
     private static final String INDEX = "Index"; //$NON-NLS-1$
 
-    private static final ImageIcon ICON_SELECT = GuiUtil.getIcon("toolbarButtonGraphics/general/Edit16.gif"); //$NON-NLS-1$
-
-//    private static final ImageIcon ICON_MENU = GuiUtil.getIcon("toolbarButtonGraphics/general/Preferences16.gif"); //$NON-NLS-1$
+    /**
+     * Keep the selection up to date with indexing.
+     */
+    private transient IndexStatusListener isl;
 
     private static int base = 1;
 
@@ -765,15 +799,15 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
 
     private transient ActionFactory actions;
 
-    private transient Book selected;
-
+    private transient Book[] selected;
     /*
      * GUI Components
      */
-    private BooksComboBoxModel mdlBible;
+    private BibleComboBoxModelSet quickSet;
     private PassageSelectionPane dlgSelect;
-    private JTextField txtKey;
-    private JTextField txtSearch;
+    private ParallelBookPicker biblePicker;
+    protected JTextField txtKey;
+    protected JTextField txtSearch;
     private JButton btnAdvanced;
     private JButton btnSearch;
     private JButton btnKey;
@@ -797,7 +831,7 @@ public class DisplaySelectPane extends JPanel implements KeyChangeListener
     /**
      * Who is interested in things this DisplaySelectPane does
      */
-    private EventListenerList listeners;
+    private transient EventListenerList listeners;
 
     /**
      * How may hits to show when the search results are ranked.
