@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: EditSitePane.java 1017 2006-03-01 16:18:45Z dmsmith $
+ * ID: $Id: EditSitePane.java 1905 2008-07-25 03:09:06Z dmsmith $
  */
 package org.crosswire.bibledesktop.book.install;
 
@@ -25,12 +25,15 @@ import java.awt.BorderLayout;
 import java.awt.Component;
 import java.awt.Dimension;
 import java.awt.FlowLayout;
+import java.awt.Frame;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
 import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.KeyEvent;
+import java.io.IOException;
+import java.io.ObjectInputStream;
 
 import javax.swing.BorderFactory;
 import javax.swing.JButton;
@@ -54,6 +57,8 @@ import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
 
 import org.crosswire.common.swing.ActionFactory;
+import org.crosswire.common.swing.CWOptionPane;
+import org.crosswire.common.swing.CWScrollPane;
 import org.crosswire.common.swing.FixedSplitPane;
 import org.crosswire.common.swing.GuiUtil;
 import org.crosswire.jsword.book.install.InstallManager;
@@ -91,9 +96,8 @@ public class EditSitePane extends JPanel
         actions = new ActionFactory(EditSitePane.class, this);
 
         lstSite = new JList(new InstallManagerComboBoxModel(imanager));
-        JScrollPane scrSite = new JScrollPane();
-        scrSite.add(lstSite, null);
-        scrSite.getViewport().add(lstSite, null);
+        JScrollPane scrSite = new CWScrollPane(lstSite);
+
         lstSite.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
         lstSite.addListSelectionListener(new ListSelectionListener()
         {
@@ -173,17 +177,18 @@ public class EditSitePane extends JPanel
         siteEditorPane = new JPanel();
         siteEditorPane.setLayout(new GridBagLayout());
         JPanel pnlMain = new JPanel();
+        pnlMain.setPreferredSize(new Dimension(300, 300));
         pnlMain.setLayout(new GridBagLayout());
-        pnlMain.add(lblMesg, new GridBagConstraints(0, 0, 2, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(10, 10, 10, 10), 0, 0));
-        pnlMain.add(lblName, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(2, 10, 2, 2), 0, 0));
+        pnlMain.add(lblMesg, new GridBagConstraints(0, 0, 2, 1, 0.0, 0.0, GridBagConstraints.LINE_START, GridBagConstraints.HORIZONTAL, new Insets(10, 10, 10, 10), 0, 0));
+        pnlMain.add(lblName, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, GridBagConstraints.LINE_END, GridBagConstraints.NONE, new Insets(2, 10, 2, 2), 0, 0));
         pnlMain.add(txtName, new GridBagConstraints(1, 1, 1, 1, 1.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(2, 2, 2, 10), 0, 0));
         // If there is only one type, then don't give the user a choice
         if (imanager.getInstallerFactoryNames().size() > 1)
         {
-            pnlMain.add(lblType, new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(2, 10, 2, 2), 0, 0));
+            pnlMain.add(lblType, new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0, GridBagConstraints.LINE_END, GridBagConstraints.NONE, new Insets(2, 10, 2, 2), 0, 0));
             pnlMain.add(cboType, new GridBagConstraints(1, 2, 1, 1, 1.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(2, 2, 2, 10), 0, 0));
         }
-        pnlMain.add(new JSeparator(), new GridBagConstraints(0, 3, 2, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(10, 10, 10, 10), 0, 0));
+        pnlMain.add(new JSeparator(), new GridBagConstraints(0, 3, 2, 1, 0.0, 0.0, GridBagConstraints.LINE_START, GridBagConstraints.HORIZONTAL, new Insets(10, 10, 10, 10), 0, 0));
         pnlMain.add(siteEditorPane, new GridBagConstraints(0, 4, 2, 1, 1.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
         pnlMain.add(pnlBtn2, new GridBagConstraints(0, 5, 2, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
 
@@ -201,8 +206,9 @@ public class EditSitePane extends JPanel
 
         pnlAction = new JPanel();
         pnlAction.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
-        pnlAction.setLayout(new FlowLayout(FlowLayout.RIGHT));
+        pnlAction.setLayout(new FlowLayout(FlowLayout.TRAILING));
         pnlAction.add(btnClose, null);
+        GuiUtil.applyDefaultOrientation(this);
     }
 
     /**
@@ -211,7 +217,8 @@ public class EditSitePane extends JPanel
      */
     public void showInDialog(Component parent)
     {
-        dlgMain = new JDialog(JOptionPane.getFrameForComponent(parent));
+        Frame root = JOptionPane.getFrameForComponent(parent);
+        dlgMain = new JDialog(root);
 
         ActionListener closer = new ActionListener()
         {
@@ -227,17 +234,20 @@ public class EditSitePane extends JPanel
         dlgMain.getContentPane().add(new JPanel(), BorderLayout.NORTH);
         dlgMain.getContentPane().add(pnlAction, BorderLayout.SOUTH);
         dlgMain.getContentPane().add(this, BorderLayout.CENTER);
-        dlgMain.getContentPane().add(new JPanel(), BorderLayout.EAST);
-        dlgMain.getContentPane().add(new JPanel(), BorderLayout.WEST);
+        dlgMain.getContentPane().add(new JPanel(), BorderLayout.LINE_END);
+        dlgMain.getContentPane().add(new JPanel(), BorderLayout.LINE_START);
         dlgMain.getRootPane().setDefaultButton(btnClose);
         dlgMain.getRootPane().registerKeyboardAction(closer, esc, JComponent.WHEN_IN_FOCUSED_WINDOW);
         dlgMain.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
         dlgMain.setTitle(Msg.EDIT_SITE_TITLE.toString());
+        dlgMain.setResizable(true);
         dlgMain.setModal(true);
 
-        GuiUtil.setSize(dlgMain, new Dimension(480, 320));
-        GuiUtil.centerWindow(dlgMain);
+        GuiUtil.setSize(dlgMain, new Dimension(750, 400));
+        GuiUtil.centerOnScreen(dlgMain);
+        GuiUtil.applyDefaultOrientation(dlgMain);
         dlgMain.setVisible(true);
+        dlgMain.toFront();
     }
 
     /**
@@ -252,7 +262,7 @@ public class EditSitePane extends JPanel
     /**
      * The name field has been updated, so we need to check the entry is valid
      */
-    protected void siteUpdate()
+    public final void siteUpdate()
     {
         if (txtName.isEditable())
         {
@@ -277,7 +287,7 @@ public class EditSitePane extends JPanel
     /**
      * The installer type combo box has been changed
      */
-    protected void newType()
+    /*private*/ final void newType()
     {
         if (userInitiated)
         {
@@ -343,7 +353,7 @@ public class EditSitePane extends JPanel
         String name = (String) lstSite.getSelectedValue();
         if (name == null)
         {
-            JOptionPane.showMessageDialog(this, Msg.NO_SELECTED_SITE.toString(), Msg.NO_SITE.toString(), JOptionPane.INFORMATION_MESSAGE);
+            CWOptionPane.showMessageDialog(this, Msg.NO_SELECTED_SITE.toString(), Msg.NO_SITE.toString(), JOptionPane.INFORMATION_MESSAGE);
             return;
         }
 
@@ -369,7 +379,7 @@ public class EditSitePane extends JPanel
             return;
         }
 
-        if (JOptionPane.showConfirmDialog(this, Msg.CONFIRM_DELETE_SITE.toString(name), Msg.DELETE_SITE.toString(), JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION)
+        if (CWOptionPane.showConfirmDialog(this, Msg.CONFIRM_DELETE_SITE.toString(name), Msg.DELETE_SITE.toString(), JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION)
         {
             imanager.removeInstaller(name);
         }
@@ -402,9 +412,9 @@ public class EditSitePane extends JPanel
     public void doSave()
     {
         String name = txtName.getText();
+        siteEditor.save();
         Installer installer = siteEditor.getInstaller();
         imanager.addInstaller(name, installer);
-        siteEditor.save();
 
         clear();
         editName = null;
@@ -515,11 +525,28 @@ public class EditSitePane extends JPanel
         {
             siteEditor = SiteEditorFactory.createSiteEditor(installer);
             siteEditorPane.add((Component) siteEditor, new GridBagConstraints(0, 0, 1, 1, 1.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
+            GuiUtil.applyDefaultOrientation(siteEditorPane);
         }
 
         GuiUtil.refresh(this);
     }
 
+    /**
+     * Serialization support.
+     * 
+     * @param is
+     * @throws IOException
+     * @throws ClassNotFoundException
+     */
+    private void readObject(ObjectInputStream is) throws IOException, ClassNotFoundException
+    {
+        // Broken but we don't serialize views
+        imanager = null;
+        editInstaller = null;
+        actions = new ActionFactory(EditSitePane.class, this);
+        is.defaultReadObject();
+    }
+
     private static final String ADD = "Add"; //$NON-NLS-1$
     private static final String EDIT = "Edit"; //$NON-NLS-1$
     private static final String DELETE = "Delete"; //$NON-NLS-1$
@@ -591,7 +618,7 @@ public class EditSitePane extends JPanel
 
     /*
      * Components for the dialog box including the button bar at the bottom.
-     * These are separaed in this way in case this component is reused in a
+     * These are separated in this way in case this component is reused in a
      * larger context.
      */
     protected JDialog dlgMain;
