@@ -17,12 +17,16 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: SitePane.java 1068 2006-04-08 02:20:41Z dmsmith $
+ * ID: $Id: SitePane.java 1890 2008-07-09 12:15:15Z dmsmith $
  */
 package org.crosswire.bibledesktop.book.install;
 
 import java.awt.BorderLayout;
 import java.awt.Component;
+import java.awt.Font;
+import java.awt.GridLayout;
+import java.io.IOException;
+import java.io.ObjectInputStream;
 
 import javax.swing.BorderFactory;
 import javax.swing.JButton;
@@ -42,8 +46,13 @@ import javax.swing.tree.TreeNode;
 import javax.swing.tree.TreePath;
 import javax.swing.tree.TreeSelectionModel;
 
+import org.crosswire.common.icu.NumberShaper;
 import org.crosswire.common.swing.ActionFactory;
+import org.crosswire.common.swing.CWOptionPane;
+import org.crosswire.common.swing.CWScrollPane;
 import org.crosswire.common.swing.FixedSplitPane;
+import org.crosswire.common.swing.FontChooser;
+import org.crosswire.common.util.Language;
 import org.crosswire.common.util.Reporter;
 import org.crosswire.jsword.book.Book;
 import org.crosswire.jsword.book.BookCategory;
@@ -58,6 +67,7 @@ import org.crosswire.jsword.book.install.InstallException;
 import org.crosswire.jsword.book.install.Installer;
 import org.crosswire.jsword.index.IndexManager;
 import org.crosswire.jsword.index.IndexManagerFactory;
+import org.crosswire.jsword.util.WebWarning;
 
 /**
  * A panel for use within a SitesPane to display one set of Books that are
@@ -95,11 +105,13 @@ public class SitePane extends JPanel
 
         actions = new ActionFactory(SitePane.class, this);
 
+        shaper = new NumberShaper();
+
         BookList bl = installer;
         if (bl == null)
         {
-            bl = Books.installed();
-            bl.addBooksListener(new CustomBooksListener());
+                bl = Books.installed();
+                bl.addBooksListener(new CustomBooksListener());
         }
 
         initialize(labelAcronymn, bl);
@@ -195,7 +207,7 @@ public class SitePane extends JPanel
         display = new TextPaneBookMetaDataDisplay();
         lblSelected.setLabelFor(display.getComponent());
 
-        JScrollPane scrSelected = new JScrollPane();
+        JScrollPane scrSelected = new CWScrollPane();
         JPanel panel = new JPanel();
         panel.setLayout(new BorderLayout());
         panel.add(lblSelected, BorderLayout.PAGE_START);
@@ -229,30 +241,24 @@ public class SitePane extends JPanel
             }
         });
 
-        JScrollPane scroller = new JScrollPane();
-        scroller.getViewport().add(treAvailable);
-
-        return scroller;
+        return new CWScrollPane(treAvailable);
     }
 
     private TreeModel createTreeModel(BookList books)
     {
         // return new BooksTreeModel(books);
         BookSet bmds = new BookSet(books.getBooks());
-        TreeNode bookRoot = new BookNode("root", bmds, 0, new Object[] {BookMetaData.KEY_CATEGORY, BookMetaData.KEY_LANGUAGE}); //$NON-NLS-1$
+        TreeNode bookRoot = new BookNode("root", bmds, 0, new Object[] {BookMetaData.KEY_CATEGORY, BookMetaData.KEY_XML_LANG}); //$NON-NLS-1$
         return new DefaultTreeModel(bookRoot);
     }
 
-    // provide for backward compatibility
     private Book getBook(Object anObj)
     {
         Object obj = anObj;
-        // new way
         if (obj instanceof DefaultMutableTreeNode)
         {
             obj = ((DefaultMutableTreeNode) obj).getUserObject();
         }
-        // Old way
         if (obj instanceof Book)
         {
             return (Book) obj;
@@ -260,6 +266,20 @@ public class SitePane extends JPanel
         return null;
     }
 
+    private Language getLanguage(Object anObj)
+    {
+        Object obj = anObj;
+        if (obj instanceof DefaultMutableTreeNode)
+        {
+            obj = ((DefaultMutableTreeNode) obj).getUserObject();
+        }
+        if (obj instanceof Language)
+        {
+            return (Language) obj;
+        }
+        return null;
+    }
+
     /**
      *
      */
@@ -268,6 +288,7 @@ public class SitePane extends JPanel
         JPanel panel = new JPanel();
         if (installer != null)
         {
+            panel.setLayout(new GridLayout(1, 2, 3, 3));
             panel.add(new JButton(actions.getAction(INSTALL)));
             // LATER(DMS): Put back when this works
             //panel.add(new JButton(actions.getAction(INSTALL_SEARCH)));
@@ -275,8 +296,11 @@ public class SitePane extends JPanel
         }
         else
         {
+            panel.setLayout(new GridLayout(2, 2, 3, 3));
             panel.add(new JButton(actions.getAction(DELETE)));
             panel.add(new JButton(actions.getAction(UNINDEX)));
+            panel.add(new JButton(actions.getAction(CHOOSE_FONT)));
+            panel.add(new JButton(actions.getAction(UNLOCK)));
         }
         return panel;
     }
@@ -297,7 +321,8 @@ public class SitePane extends JPanel
 
         try
         {
-            if (JOptionPane.showConfirmDialog(this, Msg.CONFIRM_DELETE_BOOK.toString(new Object[] {book.getName()}),
+            String msg = shaper.shape(Msg.CONFIRM_DELETE_BOOK.toString(new Object[] {book.getName()}));
+            if (CWOptionPane.showConfirmDialog(this, msg,
                             Msg.CONFIRM_DELETE_TITLE.toString(),
                             JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION)
             {
@@ -316,6 +341,36 @@ public class SitePane extends JPanel
         }
     }
 
+    /**
+     * Unlock the current book
+     */
+    public void doUnlock()
+    {
+        TreePath path = treAvailable.getSelectionPath();
+        if (path == null)
+        {
+            return;
+        }
+
+        Object last = path.getLastPathComponent();
+        Book book = getBook(last);
+
+        String unlockKey =
+            (String) CWOptionPane.showInputDialog(this,
+                                        Msg.UNLOCK_BOOK.toString(new Object[] {book.getName()}),
+                                        Msg.UNLOCK_TITLE.toString(),
+                                        JOptionPane.QUESTION_MESSAGE,
+                                        null,
+                                        null,
+                                        book.getUnlockKey());
+
+        if (unlockKey != null && unlockKey.length() > 0)
+        {
+            book.unlock(unlockKey);
+            Books.installed().addBook(book);
+        }
+    }
+
     /**
      * Delete the current book
      */
@@ -333,14 +388,12 @@ public class SitePane extends JPanel
         try
         {
             IndexManager imanager = IndexManagerFactory.getIndexManager();
-            if (imanager.isIndexed(book))
+            if (imanager.isIndexed(book)
+                && CWOptionPane.showConfirmDialog(this, Msg.CONFIRM_UNINSTALL_BOOK.toString(new Object[] {book.getName()}),
+                                              Msg.CONFIRM_UNINSTALL_TITLE.toString(),
+                                              JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION)
             {
-                if (JOptionPane.showConfirmDialog(this, Msg.CONFIRM_UNINSTALL_BOOK.toString(new Object[] {book.getName()}),
-                                Msg.CONFIRM_UNINSTALL_TITLE.toString(),
-                                JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION)
-                {
-                    imanager.deleteIndex(book);
-                }
+                imanager.deleteIndex(book);
             }
             actions.getAction(UNINDEX).setEnabled(imanager.isIndexed(book));
         }
@@ -359,8 +412,17 @@ public class SitePane extends JPanel
         {
             try
             {
-                installer.reloadBookList();
-                setTreeModel(installer);
+                int webAccess = InternetWarning.GRANTED;
+                if (WebWarning.instance().isShown())
+                {
+                    webAccess = InternetWarning.showDialog(this, "?"); //$NON-NLS-1$
+                }
+
+                if (webAccess == InternetWarning.GRANTED)
+                {
+                    installer.reloadBookList();
+                    setTreeModel(installer);
+                }
             }
             catch (InstallException ex)
             {
@@ -385,6 +447,17 @@ public class SitePane extends JPanel
             return;
         }
 
+        int webAccess = InternetWarning.GRANTED;
+        if (WebWarning.instance().isShown())
+        {
+            webAccess = InternetWarning.showDialog(this, "?"); //$NON-NLS-1$
+        }
+
+        if (webAccess != InternetWarning.GRANTED)
+        {
+            return;
+        }
+
         Object last = path.getLastPathComponent();
         Book name = getBook(last);
 
@@ -399,7 +472,14 @@ public class SitePane extends JPanel
             }
 
             float size = installer.getSize(name) / 1024.0F;
-            if (JOptionPane.showConfirmDialog(this, Msg.SIZE.toString(new Object[] {name.getName(), new Float(size)}),
+            Msg msg = Msg.KB_SIZE;
+            if (size > 1024.0F)
+            {
+                size /= 1024.0F;
+                msg = Msg.MB_SIZE;
+            }
+
+            if (CWOptionPane.showConfirmDialog(this, msg.toString(new Object[] {name.getName(), new Float(size)}),
                             Msg.CONFIRMATION_TITLE.toString(),
                             JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION)
             {
@@ -422,16 +502,36 @@ public class SitePane extends JPanel
         TreePath path = treAvailable.getSelectionPath();
         if (path != null)
         {
-            try
-            {
-                Object last = path.getLastPathComponent();
-                Book book = getBook(last);
-                IndexResolver.scheduleIndex(book, this);
-            }
-            catch (Exception ex)
-            {
-                Reporter.informUser(this, ex);
-            }
+            Object last = path.getLastPathComponent();
+            Book book = getBook(last);
+            IndexResolver.scheduleIndex(book, this);
+        }
+    }
+
+    /**
+     * Get a font for the current selection
+     */
+    public void doChooseFont()
+    {
+        TreePath path = treAvailable.getSelectionPath();
+        if (path == null)
+        {
+            return;
+        }
+
+        Object last = path.getLastPathComponent();
+        Book book = getBook(last);
+        if (book != null)
+        {
+            Font picked = FontChooser.showDialog(this, Msg.FONT_CHOOSER.toString(), BookFont.instance().getFont(book));
+            BookFont.instance().setFont(book, picked);
+        }
+
+        Language language = getLanguage(last);
+        if (language != null)
+        {
+            Font picked = FontChooser.showDialog(this, Msg.FONT_CHOOSER.toString(), BookFont.instance().getFont(language));
+            BookFont.instance().setFont(language, picked);
         }
     }
 
@@ -442,25 +542,23 @@ public class SitePane extends JPanel
     {
         TreePath path = treAvailable.getSelectionPath();
 
-        boolean bookSelected = false;
         Book book = null;
+        Language lang = null;
         if (path != null)
         {
             Object last = path.getLastPathComponent();
             book = getBook(last);
-            if (book != null)
-            {
-                bookSelected = true;
-            }
+            lang = getLanguage(last);
         }
+
         display.setBook(book);
 
-        boolean canInstall = bookSelected && book.isSupported() && !book.isEnciphered();
-        IndexManager imanager = IndexManagerFactory.getIndexManager();
-        actions.getAction(DELETE).setEnabled(bookSelected && book.getDriver().isDeletable(book));
-        actions.getAction(UNINDEX).setEnabled(bookSelected && imanager.isIndexed(book));
-        actions.getAction(INSTALL).setEnabled(canInstall);
-        actions.getAction(INSTALL_SEARCH).setEnabled(canInstall && book.getBookCategory() == BookCategory.BIBLE);
+        actions.getAction(DELETE).setEnabled(book != null && book.getDriver().isDeletable(book));
+        actions.getAction(UNLOCK).setEnabled(book != null && book.isEnciphered());
+        actions.getAction(UNINDEX).setEnabled(book != null && IndexManagerFactory.getIndexManager().isIndexed(book));
+        actions.getAction(INSTALL).setEnabled(book != null && book.isSupported());
+        actions.getAction(INSTALL_SEARCH).setEnabled(book != null && book.isSupported() && book.getBookCategory() == BookCategory.BIBLE);
+        actions.getAction(CHOOSE_FONT).setEnabled(book != null || lang != null);
     }
 
     public void setTreeModel(BookList books)
@@ -469,9 +567,9 @@ public class SitePane extends JPanel
     }
 
     /**
-     * When new books are added we need to relfect the change in this tree.
+     * When new books are added we need to reflect the change in this tree.
      */
-    private final class CustomBooksListener implements BooksListener
+    final class CustomBooksListener implements BooksListener
     {
         /* (non-Javadoc)
          * @see org.crosswire.jsword.book.BooksListener#bookAdded(org.crosswire.jsword.book.BooksEvent)
@@ -490,6 +588,21 @@ public class SitePane extends JPanel
         }
     }
 
+    /**
+     * Serialization support.
+     * 
+     * @param is
+     * @throws IOException
+     * @throws ClassNotFoundException
+     */
+    private void readObject(ObjectInputStream is) throws IOException, ClassNotFoundException
+    {
+        // Broken but we don't serialize views
+        installer = null;
+        display = null;
+        actions = new ActionFactory(SitePane.class, this);
+        is.defaultReadObject();
+    }
 
     private static final String INSTALLED_BOOKS_LABEL = "InstalledBooksLabel"; //$NON-NLS-1$
     private static final String AVAILABLE_BOOKS_LABEL = "AvailableBooksLabel"; //$NON-NLS-1$
@@ -498,6 +611,8 @@ public class SitePane extends JPanel
     private static final String INSTALL = "Install"; //$NON-NLS-1$
     private static final String INSTALL_SEARCH = "InstallSearch"; //$NON-NLS-1$
     private static final String DELETE = "Delete"; //$NON-NLS-1$
+    private static final String UNLOCK = "Unlock"; //$NON-NLS-1$
+    private static final String CHOOSE_FONT = "ChooseFont"; //$NON-NLS-1$
     private static final String UNINDEX = "Unindex"; //$NON-NLS-1$
 
     /**
@@ -510,6 +625,7 @@ public class SitePane extends JPanel
      */
     private transient ActionFactory actions;
 
+    private NumberShaper shaper;
     /*
      * GUI Components
      */
