@@ -17,13 +17,13 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: BookDataDisplayFactory.java 1154 2006-10-10 23:33:39Z dmsmith $
+ * ID: $Id: BookDataDisplayFactory.java 1771 2008-03-08 02:29:56Z dmsmith $
  */
 package org.crosswire.bibledesktop.display;
 
 import java.io.IOException;
 
-import org.crosswire.common.util.ClassUtil;
+import org.crosswire.common.util.PluginUtil;
 
 /**
  * Factory for OSIS renderers.
@@ -49,7 +49,7 @@ public final class BookDataDisplayFactory
         Exception ex = null;
         try
         {
-            return (BookDataDisplay) ClassUtil.getImplementation(BookDataDisplay.class);
+            return (BookDataDisplay) PluginUtil.getImplementation(BookDataDisplay.class);
         }
         catch (ClassCastException e)
         {
