@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: TreeConfigEditor.java 1476 2007-07-06 15:27:39Z dmsmith $
+ * ID: $Id: TreeConfigEditor.java 1916 2008-07-29 03:25:16Z dmsmith $
  */
 package org.crosswire.common.config.swing;
 
@@ -34,6 +34,7 @@ import javax.swing.BorderFactory;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
 import javax.swing.JScrollPane;
+import javax.swing.JSplitPane;
 import javax.swing.JTree;
 import javax.swing.SwingConstants;
 import javax.swing.event.EventListenerList;
@@ -48,10 +49,12 @@ import javax.swing.tree.TreePath;
 import org.crosswire.common.config.Choice;
 import org.crosswire.common.config.Config;
 import org.crosswire.common.swing.CWScrollPane;
+import org.crosswire.common.swing.FixedSplitPane;
 import org.crosswire.common.swing.FormPane;
+import org.crosswire.common.swing.GuiUtil;
 
 /**
- * A Tabbed view of a config class.
+ * A Configuration Editor that provides a tree for navigating to options.
  *
  * @see gnu.lgpl.License for license details.
  *      The copyright to this program is held by it's authors.
@@ -70,17 +73,17 @@ public class TreeConfigEditor extends AbstractConfigEditor
         JPanel panel = new JPanel();
         JPanel blank = new JPanel();
         DefaultTreeCellRenderer dtcr = new DefaultTreeCellRenderer();
-
+        // prevent truncation (This is a hack!)
+        dtcr.setPreferredSize(new Dimension(1200, 100));
         ctm = new ConfigureTreeModel();
         tree = new JTree();
         title = new JLabel();
         deck = new JPanel();
         layout = new CardLayout();
 
-        blank.add(new JLabel(Msg.SELECT_SUBNODE.toString()));
+        blank.add(new JLabel(UserMsg.SELECT_SUBNODE.toString()));
 
         deck.setLayout(layout);
-        deck.setBorder(BorderFactory.createEmptyBorder(10, 0, 0, 0));
         deck.add(blank, BLANK);
 
         dtcr.setLeafIcon(TASK_ICON_SMALL);
@@ -88,7 +91,6 @@ public class TreeConfigEditor extends AbstractConfigEditor
         // These settings will need to change if we have a true tree.
         tree.setModel(ctm);
         tree.setCellRenderer(dtcr);
-        tree.setPreferredSize(new Dimension(150, 150));
         tree.setShowsRootHandles(false);
         tree.setRootVisible(false);
         tree.putClientProperty("JTree.lineStyle", "None"); //$NON-NLS-1$ //$NON-NLS-2$
@@ -102,34 +104,32 @@ public class TreeConfigEditor extends AbstractConfigEditor
         });
 
         title.setIcon(TASK_ICON_LARGE);
-        title.setFont(new Font(getFont().getName(), Font.PLAIN, 16));
-        title.setPreferredSize(new Dimension(30, 30));
+        title.setFont(getFont().deriveFont(Font.PLAIN, 16));
         title.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
         title.setBackground(Color.gray);
         title.setForeground(Color.white);
         title.setOpaque(true);
-        title.setText(Msg.PROPERTIES.toString());
+        title.setText(UserMsg.PROPERTIES.toString());
         title.setAlignmentX(SwingConstants.LEADING);
 
-        // Use this if you want to have the tree touch the bottom. Then add
-        // the button panel to content.South
-        // JPanel content = new JPanel();
-        // content.setLayout(new BorderLayout());
-        // content.add(BorderLayout.CENTER, deck);
-
         panel.setLayout(new BorderLayout());
-        panel.setBorder(BorderFactory.createEmptyBorder(0, 5, 0, 0));
+        panel.setBorder(BorderFactory.createEtchedBorder());
         panel.add(BorderLayout.NORTH, title);
         panel.add(BorderLayout.CENTER, deck);
 
-        setLayout(new BorderLayout(5, 10));
+        setLayout(new BorderLayout());
         setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
 
-        //if (cards > 1)
-        add(BorderLayout.LINE_START, new CWScrollPane(tree));
+        JSplitPane sptMain = new FixedSplitPane();
+        sptMain.setOrientation(JSplitPane.HORIZONTAL_SPLIT);
+        sptMain.setDividerLocation(0.25D);
+        sptMain.setResizeWeight(0.25D);
+        sptMain.setLeftComponent(new CWScrollPane(tree));
+        sptMain.setRightComponent(panel);
 
-        add(BorderLayout.CENTER, panel);
+        add(BorderLayout.CENTER, sptMain);
         add(BorderLayout.SOUTH, new ButtonPane(this));
+        GuiUtil.applyDefaultOrientation(this);
     }
 
     /**
@@ -166,7 +166,7 @@ public class TreeConfigEditor extends AbstractConfigEditor
         {
             JScrollPane scroll = new CWScrollPane(card);
             scroll.setBorder(BorderFactory.createEmptyBorder());
-            deck.add(path, scroll);
+            deck.add(scroll, path);
         }
     }
 
@@ -189,7 +189,7 @@ public class TreeConfigEditor extends AbstractConfigEditor
     /**
      * Used to update the configuration panel whenever someone
      * selects a different item form the tree on the LHS of the
-     * configuation dialog.
+     * configuration dialog.
      */
     public void selectCard()
     {
@@ -199,7 +199,7 @@ public class TreeConfigEditor extends AbstractConfigEditor
             return;
         }
 
-        title.setText(obj + " " + Msg.PROPERTIES); //$NON-NLS-1$
+        title.setText(obj + " " + UserMsg.PROPERTIES); //$NON-NLS-1$
 
         // Get the name of the current deck
         Object[] list = tree.getSelectionPath().getPath();
@@ -216,6 +216,7 @@ public class TreeConfigEditor extends AbstractConfigEditor
         }
 
         String key = path.toString();
+        GuiUtil.applyDefaultOrientation(deck);
         if (decks.containsKey(key))
         {
             layout.show(deck, key);
