@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: QuickHelpDialog.java 1476 2007-07-06 15:27:39Z dmsmith $
+ * ID: $Id: QuickHelpDialog.java 1905 2008-07-25 03:09:06Z dmsmith $
  */
 package org.crosswire.common.swing;
 
@@ -124,7 +124,7 @@ public class QuickHelpDialog extends JDialog
     {
         if (visible)
         {
-            GuiUtil.centerWindow(this);
+            GuiUtil.centerOnScreen(this);
         }
 
         super.setVisible(visible);
