@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: License.java 1083 2006-04-18 18:13:36Z dmsmith $
+ * ID: $Id: License.java 1781 2008-03-15 12:19:11Z dmsmith $
  */
 package gnu.gpl;
 
@@ -384,22 +384,22 @@ public class License
 
     /**
      * Get the Warranty.
-     * 
+     *
      * @return the warranty for this program
      */
     public String getWarranty()
     {
-        return Msg.WARRANTY.toString(name);
+        return UserMsg.WARRANTY.toString(name);
     }
 
     /**
      * Get the license distribution terms.
-     * 
+     *
      * @return the details of this program's distribution license
      */
     public String getDetails()
     {
-        return Msg.DETAILS.toString(name);
+        return UserMsg.DETAILS.toString(name);
     }
 
     /**
