@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: Config.java 1470 2007-07-03 15:18:54Z dmsmith $
+ * ID: $Id: Config.java 1884 2008-06-24 19:20:22Z dmsmith $
  */
 package org.crosswire.common.config;
 
@@ -141,7 +141,10 @@ public class Config
             try
             {
                 Choice choice = ChoiceFactory.getChoice(element, configResources);
-                add(choice);
+                if (!choice.isIgnored())
+                {
+                    add(choice);
+                }
             }
             catch (StartupException e)
             {
@@ -266,14 +269,14 @@ public class Config
             String key = (String) iter.next();
             Choice choice = getChoice(key);
 
-            String oldValue = choice.getString();
+            String oldValue = choice.getString();   // never returns null
             String newValue = local.getProperty(key);
 
             // The new value shouldn't really be blank - obviously this
             // choice has just been added, substitute the default.
-            if (newValue == null || newValue.length() == 0)
+            if ((newValue == null) || (newValue.length() == 0))
             {
-                if (oldValue == null)
+                if ((oldValue == null) || (oldValue.length() == 0))
                 {
                     continue;
                 }
@@ -302,71 +305,10 @@ public class Config
                 }
             }
         }
-//        int highestChange = Choice.PRIORITY_LOWEST;
-//
-//        if (force)
-//        {
-//            log.info("Force=true, all changes will propagate regardless"); //$NON-NLS-1$
-//        }
-//
-//        for (int priority = Choice.PRIORITY_SYSTEM; priority >= Choice.PRIORITY_LOWEST; priority--)
-//        {
-//            log.info("Settings for priority level=" + priority); //$NON-NLS-1$
-//
-//            Iterator it = keys.iterator();
-//            while (it.hasNext())
-//            {
-//                String key = (String) it.next();
-//                Choice choice = getChoice(key);
-//
-//                if (choice.getPriority() == priority)
-//                {
-//                    String oldValue = choice.getString();
-//                    String newValue = local.getProperty(key);
-//
-//                    // The new value shouldn't really be blank - obviously this
-//                    // choice has just been added, substitute the default.
-//                    if (newValue == null)
-//                    {
-//                        local.put(key, oldValue);
-//                        newValue = oldValue;
-//                    }
-//
-//                    try
-//                    {
-//                        // If a value has not changed, we only call setString()
-//                        // if force==true or if a higher priority choice has
-//                        // changed.
-//                        if (force
-//                            || priority < highestChange
-//                            || !newValue.equals(oldValue))
-//                        {
-//                            log.info("Setting " + key + "=" + newValue + " (was " + oldValue + ")"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
-//                            choice.setString(newValue);
-//
-//                            if (priority > highestChange)
-//                            {
-//                                highestChange = priority;
-//
-//                                if (!force)
-//                                {
-//                                    log.info("Change at level " + highestChange + ", all changes will propagate regardless"); //$NON-NLS-1$ //$NON-NLS-2$
-//                                }
-//                            }
-//                        }
-//                    }
-//                    catch (Exception ex)
-//                    {
-//                        log.warn("Failure setting " + key + "=" + newValue, ex);  //$NON-NLS-1$ //$NON-NLS-2$
-//                        Reporter.informUser(this, new ConfigException(Msg.CONFIG_SETFAIL, ex, new Object[] { choice.getFullPath() } ));
-//                    }
-//                }
-//            }
-//        }
     }
 
     /**
-     * Take the data stored permanetly and copy it to the local
+     * Take the data stored permanently and copy it to the local
      * storage area, using the specified stream
      */
     public void setProperties(Properties prop)
@@ -377,7 +319,9 @@ public class Config
             String key = (String) iter.next();
             String value = prop.getProperty(key);
 
-            if (value != null)
+            Choice model = getChoice(key);
+            // Only if a value was stored and it should be stored then we use it.
+            if (value != null && model != null && model.isSaveable())
             {
                 local.put(key, value);
             }
