@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: NetUtil.java 1470 2007-07-03 15:18:54Z dmsmith $
+ * ID: $Id: NetUtil.java 1887 2008-07-08 03:15:12Z dmsmith $
  */
 package org.crosswire.common.util;
 
@@ -56,7 +56,7 @@ import java.util.jar.JarEntry;
 public final class NetUtil
 {
     /**
-     * Basic constructor - ensure that we can't be instansiated
+     * Basic constructor - ensure that we can't be instantiated
      */
     private NetUtil()
     {
@@ -135,7 +135,7 @@ public final class NetUtil
         // If it is a file, except
         if (file.isFile())
         {
-            throw new MalformedURLException(Msg.IS_FILE.toString(orig));
+            throw new MalformedURLException(UserMsg.IS_FILE.toString(orig));
         }
 
         // Is it already a directory ?
@@ -146,7 +146,7 @@ public final class NetUtil
             // Did that work?
             if (!file.isDirectory())
             {
-                throw new MalformedURLException(Msg.CREATE_DIR_FAIL.toString(orig));
+                throw new MalformedURLException(UserMsg.CREATE_DIR_FAIL.toString(orig));
             }
         }
     }
@@ -165,7 +165,7 @@ public final class NetUtil
         // If it is a file, except
         if (file.isDirectory())
         {
-            throw new MalformedURLException(Msg.IS_DIR.toString(orig));
+            throw new MalformedURLException(UserMsg.IS_DIR.toString(orig));
         }
 
         // Is it already a directory ?
@@ -177,7 +177,7 @@ public final class NetUtil
             // Did that work?
             if (!file.isFile())
             {
-                throw new MalformedURLException(Msg.CREATE_FILE_FAIL.toString(orig));
+                throw new MalformedURLException(UserMsg.CREATE_FILE_FAIL.toString(orig));
             }
         }
     }
@@ -227,7 +227,7 @@ public final class NetUtil
      * If there is a writable directory or file at the other end of this URI return true.
      * Note non file: type URIs will always return false
      * @param orig The URI to check
-     * @return true if the URI points at a file: directory
+     * @return true if the URI points at a writable file or directory
      */
     public static boolean canWrite(URI orig)
     {
@@ -239,6 +239,22 @@ public final class NetUtil
         return new File(orig.getPath()).canWrite();
     }
 
+    /**
+     * If there is a readable directory or file at the other end of this URI return true.
+     * Note non file: type URIs will always return false
+     * @param orig The URI to check
+     * @return true if the URI points at a readable file or directory
+     */
+    public static boolean canRead(URI orig)
+    {
+        if (!orig.getScheme().equals(PROTOCOL_FILE))
+        {
+            return false;
+        }
+
+        return new File(orig.getPath()).canRead();
+    }
+
     /**
      * Move a URI from one place to another. Currently this only works for
      * file: URIs, however the interface should not need to change to
@@ -365,8 +381,8 @@ public final class NetUtil
                            orig.getHost(),
                            orig.getPort(),
                            newFile,
-                           orig.getQuery(),
-                           orig.getFragment());
+                           "", //$NON-NLS-1$
+                           ""); //$NON-NLS-1$
         }
         catch (URISyntaxException e)
         {
@@ -385,39 +401,34 @@ public final class NetUtil
         String extra = anExtra;
         try
         {
+            StringBuffer path = new StringBuffer(orig.getPath());
+            char lastChar = path.charAt(path.length() - 1);
             char firstChar = extra.charAt(0);
             if (isSeparator(firstChar))
             {
-                extra = extra.substring(1);
-            }
-
-            if (orig.getScheme().equals(PROTOCOL_FILE))
-            {
-                String file = orig.toString();
-                char lastChar = file.charAt(file.length() - 1);
                 if (isSeparator(lastChar))
                 {
-                    return new URI(orig.getScheme(),
-                                   orig.getUserInfo(),
-                                   orig.getHost(),
-                                   orig.getPort(),
-                                   orig.getPath() + extra,
-                                   orig.getQuery(),
-                                   orig.getFragment());
+                    path.append(extra.substring(1));
+                }
+                else
+                {
+                    path.append(extra);
                 }
-                return new URI(orig.getScheme(),
-                               orig.getUserInfo(),
-                               orig.getHost(),
-                               orig.getPort(),
-                               orig.getPath() + File.separator + extra,
-                               orig.getQuery(),
-                               orig.getFragment());
             }
+            else
+            {
+                if (!isSeparator(lastChar))
+                {
+                    path.append(SEPARATOR);
+                }
+                path.append(extra);
+            }
+
             return new URI(orig.getScheme(),
                            orig.getUserInfo(),
                            orig.getHost(),
                            orig.getPort(),
-                           orig.getPath() + SEPARATOR + extra,
+                           path.toString(),
                            orig.getQuery(),
                            orig.getFragment());
         }
@@ -550,14 +561,28 @@ public final class NetUtil
         File fdir = new File(uri.getPath());
         if (!fdir.isDirectory())
         {
-            throw new MalformedURLException(Msg.NOT_DIR.toString(uri.toString()));
+            throw new MalformedURLException(UserMsg.NOT_DIR.toString(uri.toString()));
         }
 
         return fdir.list(new URIFilterFilenameFilter(filter));
     }
 
+    /**
+     * List all the strings specified by the index file passed in.
+     * To be acceptable it must be a non-0 length string, not commented
+     * with #, and not the index file itself.
+     * @return String[] Matching results.
+     * @throws FileNotFoundException
+     */
+    public static String[] listByIndexFile(URI index) throws IOException
+    {
+        return listByIndexFile(index, new DefaultURIFilter());
+    }
+
     /**
      * List all the files specified by the index file passed in.
+     * To be acceptable it must be a non-0 length string, not commented
+     * with #, not the index file itself and acceptable by the filter.
      * @return String[] Matching results.
      * @throws FileNotFoundException
      */
@@ -769,7 +794,7 @@ public final class NetUtil
     {
         if (!uri.getScheme().equals(PROTOCOL_FILE))
         {
-            throw new MalformedURLException(Msg.NOT_FILE_URI.toString(uri));
+            throw new MalformedURLException(UserMsg.NOT_FILE_URI.toString(uri));
         }
     }
 
