@@ -17,13 +17,13 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: Defaults.java 1351 2007-05-25 16:34:16Z dmsmith $
+ * ID: $Id: Defaults.java 1744 2008-02-02 16:31:33Z dmsmith $
  */
 package org.crosswire.jsword.book;
 
-import java.util.ArrayList;
 import java.util.Iterator;
-import java.util.List;
+import java.util.Map;
+import java.util.TreeMap;
 
 import org.crosswire.common.config.ChoiceFactory;
 
@@ -446,38 +446,41 @@ public final class Defaults
         return hebrewParseDeft;
     }
 
+    /**
+     * Create book lists for every type of book.
+     */
     public static void refreshBooks()
     {
         // Create the array of Bibles
-        String[] bnames = getNameArray(BookFilters.getOnlyBibles());
+        Map bnames = getBookMap(BookFilters.getOnlyBibles());
         ChoiceFactory.getDataMap().put(BIBLE_KEY, bnames);
 
         // Create the array of Commentaries
-        String[] cnames = getNameArray(BookFilters.getCommentaries());
+        Map cnames = getBookMap(BookFilters.getCommentaries());
         ChoiceFactory.getDataMap().put(COMMENTARY_KEY, cnames);
 
         // Create the array of Dictionaries
-        String[] dnames = getNameArray(BookFilters.getDictionaries());
+        Map dnames = getBookMap(BookFilters.getDictionaries());
         ChoiceFactory.getDataMap().put(DICTIONARY_KEY, dnames);
 
         // Create the array of DailyDevotionals
-        String[] rnames = getNameArray(BookFilters.getDailyDevotionals());
+        Map rnames = getBookMap(BookFilters.getDailyDevotionals());
         ChoiceFactory.getDataMap().put(DAILY_DEVOTIONALS_KEY, rnames);
 
         // Create the array of Dictionaries
-        String[] greekDef = getNameArray(BookFilters.getGreekDefinitions());
+        Map greekDef = getBookMap(BookFilters.getGreekDefinitions());
         ChoiceFactory.getDataMap().put(GREEKDEF_KEY, greekDef);
 
         // Create the array of Dictionaries
-        String[] hebrewDef = getNameArray(BookFilters.getHebrewDefinitions());
+        Map hebrewDef = getBookMap(BookFilters.getHebrewDefinitions());
         ChoiceFactory.getDataMap().put(HEBREWDEF_KEY, hebrewDef);
 
         // Create the array of Dictionaries
-        String[] greekParse = getNameArray(BookFilters.getGreekParse());
+        Map greekParse = getBookMap(BookFilters.getGreekParse());
         ChoiceFactory.getDataMap().put(GREEKPARSE_KEY, greekParse);
 
         // Create the array of Dictionaries
-        String[] hebrewParse = getNameArray(BookFilters.getHebrewParse());
+        Map hebrewParse = getBookMap(BookFilters.getHebrewParse());
         ChoiceFactory.getDataMap().put(HEBREWPARSE_KEY, hebrewParse);
     }
 
@@ -516,18 +519,18 @@ public final class Defaults
     /**
      * Convert a filter into an array of names of Books that pass the filter.
      */
-    private static String[] getNameArray(BookFilter filter)
+    private static Map getBookMap(BookFilter filter)
     {
-        List names = new ArrayList();
+        Map books = new TreeMap(BookComparators.getDefault());
 
         Iterator iter = Books.installed().getBooks(filter).iterator();
         while (iter.hasNext())
         {
             Book book = (Book) iter.next();
-            names.add(book.getName());
+            books.put(book, book.getName());
         }
 
-        return (String[]) names.toArray(new String[names.size()]);
+        return books;
     }
 
     /**
