@@ -17,16 +17,16 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: AbstractBook.java 1161 2006-10-15 22:37:25Z dmsmith $
+ * ID: $Id: AbstractBook.java 1605 2007-08-03 21:34:46Z dmsmith $
  */
 package org.crosswire.jsword.book.basic;
 
-import java.beans.PropertyChangeListener;
 import java.util.Map;
 
 import javax.swing.event.EventListenerList;
 
 import org.crosswire.common.activate.Lock;
+import org.crosswire.common.util.Language;
 import org.crosswire.jsword.book.Book;
 import org.crosswire.jsword.book.BookCategory;
 import org.crosswire.jsword.book.BookDriver;
@@ -46,8 +46,8 @@ import org.jdom.Document;
 /**
  * AbstractBook implements a few of the more generic methods of Book.
  * This class does a lot of work in helping make search easier, and implementing
- * some basic write methods. 
- * 
+ * some basic write methods.
+ *
  * @see gnu.lgpl.License for license details.
  *      The copyright to this program is held by it's authors.
  * @author Joe Walker [joe at eireneh dot com]
@@ -142,11 +142,39 @@ public abstract class AbstractBook implements Book
     }
 
     /* (non-Javadoc)
-     * @see org.crosswire.jsword.book.BookMetaData#getFullName()
+     * @see org.crosswire.jsword.book.Book#match(java.lang.String)
      */
-    public String getFullName()
+    public boolean match(String name)
     {
-        return bmd.getFullName();
+        if (name == null)
+        {
+            return false;
+        }
+        if (name.equals(getInitials()))
+        {
+            return true;
+        }
+        if (name.equals(getName()))
+        {
+            return true;
+        }
+        if (name.equalsIgnoreCase(getInitials()))
+        {
+            return true;
+        }
+        if (name.equalsIgnoreCase(getName()))
+        {
+            return true;
+        }
+        if (name.startsWith(getInitials()))
+        {
+            return true;
+        }
+        if (name.startsWith(getName()))
+        {
+            return true;
+        }
+        return false;
     }
 
     /* (non-Javadoc)
@@ -178,7 +206,7 @@ public abstract class AbstractBook implements Book
     /* (non-Javadoc)
      * @see org.crosswire.jsword.book.BookMetaData#getLanguage()
      */
-    public String getLanguage()
+    public Language getLanguage()
     {
         return bmd.getLanguage();
     }
@@ -210,7 +238,7 @@ public abstract class AbstractBook implements Book
     /* (non-Javadoc)
      * @see org.crosswire.jsword.book.Book#getProperty(java.lang.String)
      */
-    public String getProperty(String key)
+    public Object getProperty(String key)
     {
         return bmd.getProperty(key);
     }
@@ -218,7 +246,7 @@ public abstract class AbstractBook implements Book
     /* (non-Javadoc)
      * @see org.crosswire.jsword.book.Book#putProperty(java.lang.String, java.lang.String)
      */
-    public void putProperty(String key, String value)
+    public void putProperty(String key, Object value)
     {
         bmd.putProperty(key, value);
     }
@@ -340,7 +368,7 @@ public abstract class AbstractBook implements Book
             Object[] listenerList = listeners.getListenerList();
             for (int i = 0; i <= listenerList.length - 2; i += 2)
             {
-                if (listenerList[i] == PropertyChangeListener.class)
+                if (listenerList[i] == IndexStatusListener.class)
                 {
                     IndexStatusEvent ev = new IndexStatusEvent(this, newStatus);
                     IndexStatusListener li = (IndexStatusListener) listenerList[i + 1];
@@ -352,7 +380,7 @@ public abstract class AbstractBook implements Book
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see org.crosswire.jsword.book.BookMetaData#toOSIS()
      */
     public Document toOSIS()
