@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: InstallManager.java 1470 2007-07-03 15:18:54Z dmsmith $
+ * ID: $Id: InstallManager.java 1850 2008-05-10 18:34:02Z dmsmith $
  */
 package org.crosswire.jsword.book.install;
 
@@ -30,13 +30,12 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 
-import org.crosswire.common.util.ClassUtil;
+import org.crosswire.common.util.CWProject;
 import org.crosswire.common.util.EventListenerList;
 import org.crosswire.common.util.Logger;
 import org.crosswire.common.util.NetUtil;
+import org.crosswire.common.util.PluginUtil;
 import org.crosswire.common.util.Reporter;
-import org.crosswire.common.util.ResourceUtil;
-import org.crosswire.jsword.util.Project;
 
 /**
  * A manager to abstract out the non-view specific book installation tasks.
@@ -57,8 +56,8 @@ public final class InstallManager
 
         try
         {
-            Properties sitemap = ResourceUtil.getProperties(getClass());
-            factories = ClassUtil.getImplementorsMap(InstallerFactory.class);
+            Properties sitemap = PluginUtil.getPlugin(getClass());
+            factories = PluginUtil.getImplementorsMap(InstallerFactory.class);
             int i = 0;
             for (String def = sitemap.getProperty(PREFIX + ++i); def != null; def = sitemap.getProperty(PREFIX + ++i))
             {
@@ -120,7 +119,7 @@ public final class InstallManager
             buf.append(installer.getInstallerDefinition());
             props.setProperty(PREFIX + i++, buf.toString());
         }
-        URI outputURI = Project.instance().getWritablePropertiesURI(getClass().getName());
+        URI outputURI = CWProject.instance().getWritablePropertiesURI(getClass().getName());
         try
         {
             NetUtil.storeProperties(props, outputURI, "Saved Installer Sites"); //$NON-NLS-1$
