@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: Msg.java 1466 2007-07-02 02:48:09Z dmsmith $
+ * ID: $Id: Msg.java 1772 2008-03-08 02:37:36Z dmsmith $
  */
 package org.crosswire.jsword.book.readings;
 
@@ -32,11 +32,6 @@ import org.crosswire.common.util.MsgBase;
  */
 final class Msg extends MsgBase
 {
-    static final Msg NOT_FOUND = new Msg("ReadingsBook.NotFound"); //$NON-NLS-1$
-    static final Msg FILTER_FAIL = new Msg("ReadingsBook.FilterFail"); //$NON-NLS-1$
-    static final Msg HEADING = new Msg("ReadingsBook.Heading"); //$NON-NLS-1$
-    static final Msg DECODE_ERROR = new Msg("ReadingsBook.DecodeError"); //$NON-NLS-1$
-    static final Msg TITLE = new Msg("ReadingsBookDriver.Title"); //$NON-NLS-1$
     static final Msg PARSE_FAIL = new Msg("ReadingsKey.ParseFail"); //$NON-NLS-1$
     static final Msg DRIVER_READONLY = new Msg("ReadingsKey.DriverReadonly"); //$NON-NLS-1$
 
