@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: BookType.java 1253 2007-03-16 21:16:26Z dmsmith $
+ * ID: $Id: BookType.java 1701 2007-10-24 20:15:07Z dmsmith $
  */
 package org.crosswire.jsword.book.sword;
 
@@ -29,7 +29,7 @@ import org.crosswire.jsword.book.BookException;
 
 /**
  * Data about book types.
- * 
+ *
  * @see gnu.lgpl.License for license details.
  *      The copyright to this program is held by it's authors.
  * @author Joe Walker [joe at eireneh dot com]
@@ -40,7 +40,7 @@ public abstract class BookType implements Serializable
     /**
      * Uncompressed Bibles
      */
-    public static final BookType RAW_TEXT = new BookType("RawText", BookCategory.BIBLE) //$NON-NLS-1$ 
+    public static final BookType RAW_TEXT = new BookType("RawText", BookCategory.BIBLE) //$NON-NLS-1$
     {
         protected Book getBook(SwordBookMetaData sbmd, AbstractBackend backend)
         {
@@ -49,7 +49,7 @@ public abstract class BookType implements Serializable
 
         protected AbstractBackend getBackend(SwordBookMetaData sbmd) throws BookException
         {
-            return new RawBackend(sbmd);
+            return new RawBackend(sbmd, 2);
         }
 
         /**
@@ -61,7 +61,7 @@ public abstract class BookType implements Serializable
     /**
      * Compressed Bibles
      */
-    public static final BookType Z_TEXT = new BookType("zText", BookCategory.BIBLE) //$NON-NLS-1$ 
+    public static final BookType Z_TEXT = new BookType("zText", BookCategory.BIBLE) //$NON-NLS-1$
     {
         protected Book getBook(SwordBookMetaData sbmd, AbstractBackend backend)
         {
@@ -70,12 +70,8 @@ public abstract class BookType implements Serializable
 
         protected AbstractBackend getBackend(SwordBookMetaData sbmd) throws BookException
         {
-            return getCompressedBackend(sbmd);
-        }
-
-        protected boolean isBackendSupported(SwordBookMetaData sbmd)
-        {
-            return isCompressedBackendSupported(sbmd);
+            BlockType blockType = BlockType.fromString((String) sbmd.getProperty(ConfigEntryType.BLOCK_TYPE));
+            return new ZVerseBackend(sbmd, blockType);
         }
 
         /**
@@ -87,7 +83,7 @@ public abstract class BookType implements Serializable
     /**
      * Uncompressed Commentaries
      */
-    public static final BookType RAW_COM = new BookType("RawCom", BookCategory.COMMENTARY) //$NON-NLS-1$ 
+    public static final BookType RAW_COM = new BookType("RawCom", BookCategory.COMMENTARY) //$NON-NLS-1$
     {
         protected Book getBook(SwordBookMetaData sbmd, AbstractBackend backend)
         {
@@ -96,7 +92,7 @@ public abstract class BookType implements Serializable
 
         protected AbstractBackend getBackend(SwordBookMetaData sbmd) throws BookException
         {
-            return new RawBackend(sbmd);
+            return new RawBackend(sbmd, 2);
         }
 
         /**
@@ -105,10 +101,7 @@ public abstract class BookType implements Serializable
         private static final long serialVersionUID = 3258129141898294837L;
     };
 
-    /**
-     * Compressed Commentaries
-     */
-    public static final BookType Z_COM = new BookType("zCom", BookCategory.COMMENTARY) //$NON-NLS-1$ 
+    public static final BookType RAW_COM4 = new BookType("RawCom4", BookCategory.COMMENTARY) //$NON-NLS-1$
     {
         protected Book getBook(SwordBookMetaData sbmd, AbstractBackend backend)
         {
@@ -117,12 +110,28 @@ public abstract class BookType implements Serializable
 
         protected AbstractBackend getBackend(SwordBookMetaData sbmd) throws BookException
         {
-            return getCompressedBackend(sbmd);
+            return new RawBackend(sbmd, 4);
         }
 
-        protected boolean isBackendSupported(SwordBookMetaData sbmd)
+        /**
+         * Serialization ID
+         */
+        private static final long serialVersionUID = 3258129141898294838L;
+    };
+    /**
+     * Compressed Commentaries
+     */
+    public static final BookType Z_COM = new BookType("zCom", BookCategory.COMMENTARY) //$NON-NLS-1$
+    {
+        protected Book getBook(SwordBookMetaData sbmd, AbstractBackend backend)
         {
-            return isCompressedBackendSupported(sbmd);
+            return new SwordBook(sbmd, backend);
+        }
+
+        protected AbstractBackend getBackend(SwordBookMetaData sbmd) throws BookException
+        {
+            BlockType blockType = BlockType.fromString((String) sbmd.getProperty(ConfigEntryType.BLOCK_TYPE));
+            return new ZVerseBackend(sbmd, blockType);
         }
 
         /**
@@ -134,7 +143,7 @@ public abstract class BookType implements Serializable
     /**
      * Uncompresses HREF Commentaries
      */
-    public static final BookType HREF_COM = new BookType("HREFCom", BookCategory.COMMENTARY) //$NON-NLS-1$ 
+    public static final BookType HREF_COM = new BookType("HREFCom", BookCategory.COMMENTARY) //$NON-NLS-1$
     {
         protected Book getBook(SwordBookMetaData sbmd, AbstractBackend backend)
         {
@@ -143,7 +152,7 @@ public abstract class BookType implements Serializable
 
         protected AbstractBackend getBackend(SwordBookMetaData sbmd) throws BookException
         {
-            return new RawBackend(sbmd);
+            return new RawBackend(sbmd, 2);
         }
 
         /**
@@ -155,7 +164,7 @@ public abstract class BookType implements Serializable
     /**
      * Uncompressed Commentaries
      */
-    public static final BookType RAW_FILES = new BookType("RawFiles", BookCategory.COMMENTARY) //$NON-NLS-1$ 
+    public static final BookType RAW_FILES = new BookType("RawFiles", BookCategory.COMMENTARY) //$NON-NLS-1$
     {
         protected Book getBook(SwordBookMetaData sbmd, AbstractBackend backend)
         {
@@ -164,7 +173,7 @@ public abstract class BookType implements Serializable
 
         protected AbstractBackend getBackend(SwordBookMetaData sbmd) throws BookException
         {
-            return new RawBackend(sbmd);
+            return new RawBackend(sbmd, 2);
         }
 
         /**
@@ -176,7 +185,7 @@ public abstract class BookType implements Serializable
     /**
      * 2-Byte Index Uncompressed Dictionaries
      */
-    public static final BookType RAW_LD = new BookType("RawLD", BookCategory.DICTIONARY) //$NON-NLS-1$ 
+    public static final BookType RAW_LD = new BookType("RawLD", BookCategory.DICTIONARY) //$NON-NLS-1$
     {
         protected Book getBook(SwordBookMetaData sbmd, AbstractBackend backend)
         {
@@ -201,7 +210,7 @@ public abstract class BookType implements Serializable
     /**
      * 4-Byte Index Uncompressed Dictionaries
      */
-    public static final BookType RAW_LD4 = new BookType("RawLD4", BookCategory.DICTIONARY) //$NON-NLS-1$ 
+    public static final BookType RAW_LD4 = new BookType("RawLD4", BookCategory.DICTIONARY) //$NON-NLS-1$
     {
         protected Book getBook(SwordBookMetaData sbmd, AbstractBackend backend)
         {
@@ -226,7 +235,7 @@ public abstract class BookType implements Serializable
     /**
      * Compressed Dictionaries
      */
-    public static final BookType Z_LD = new BookType("zLD", BookCategory.DICTIONARY) //$NON-NLS-1$ 
+    public static final BookType Z_LD = new BookType("zLD", BookCategory.DICTIONARY) //$NON-NLS-1$
     {
         protected Book getBook(SwordBookMetaData sbmd, AbstractBackend backend)
         {
@@ -251,7 +260,7 @@ public abstract class BookType implements Serializable
     /**
      * Generic Books
      */
-    public static final BookType RAW_GEN_BOOK = new BookType("RawGenBook", BookCategory.GENERAL_BOOK) //$NON-NLS-1$ 
+    public static final BookType RAW_GEN_BOOK = new BookType("RawGenBook", BookCategory.GENERAL_BOOK) //$NON-NLS-1$
     {
         protected Book getBook(SwordBookMetaData sbmd, AbstractBackend backend)
         {
@@ -263,11 +272,6 @@ public abstract class BookType implements Serializable
             return new GenBookBackend(sbmd);
         }
 
-        protected boolean isBackendSupported(SwordBookMetaData sbmd)
-        {
-            return true;
-        }
-
         /**
          * Serialization ID
          */
@@ -318,16 +322,7 @@ public abstract class BookType implements Serializable
      */
     public boolean isSupported(SwordBookMetaData sbmd)
     {
-        return type != null && isBackendSupported(sbmd);
-    }
-
-    /**
-     * By default the backend is supported if the BookMetaData is not null.
-     * @return true if this is a useable BackEnd
-     */
-    protected boolean isBackendSupported(SwordBookMetaData sbmd)
-    {
-        return sbmd != null;
+        return type != null && sbmd != null;
     }
 
     /**
@@ -349,33 +344,6 @@ public abstract class BookType implements Serializable
      */
     protected abstract AbstractBackend getBackend(SwordBookMetaData sbmd) throws BookException;
 
-    /**
-     * 
-     */
-    protected static AbstractBackend getCompressedBackend(SwordBookMetaData sbmd) throws BookException
-    {
-        String cStr = sbmd.getProperty(ConfigEntryType.COMPRESS_TYPE);
-        if (cStr != null)
-        {
-            return CompressionType.fromString(cStr).getBackend(sbmd);
-        }
-        assert false;
-        throw new BookException(Msg.COMPRESSION_UNSUPPORTED, new Object[] { "no compression given" }); //$NON-NLS-1$
-    }
-
-    /**
-     * 
-     */
-    protected static boolean isCompressedBackendSupported(SwordBookMetaData sbmd)
-    {
-        String cStr = sbmd.getProperty(ConfigEntryType.COMPRESS_TYPE);
-        if (cStr != null)
-        {
-            return CompressionType.fromString(cStr).isSupported();
-        }
-        return false;
-    }
-
     /**
      * The name of the BookType
      */
@@ -443,6 +411,7 @@ public abstract class BookType implements Serializable
         RAW_TEXT,
         Z_TEXT,
         RAW_COM,
+        RAW_COM4,
         Z_COM,
         RAW_COM,
         HREF_COM,
