@@ -17,11 +17,10 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: ConfigEntryTable.java 1466 2007-07-02 02:48:09Z dmsmith $
+ * ID: $Id: ConfigEntryTable.java 1887 2008-07-08 03:15:12Z dmsmith $
  */
 package org.crosswire.jsword.book.sword;
 
-import java.awt.ComponentOrientation;
 import java.io.BufferedReader;
 import java.io.ByteArrayInputStream;
 import java.io.File;
@@ -32,10 +31,12 @@ import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
 import java.io.Writer;
 import java.util.HashMap;
-import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
+import org.crosswire.common.util.Language;
 import org.crosswire.common.util.Languages;
 import org.crosswire.common.util.Logger;
 import org.crosswire.common.util.Reporter;
@@ -87,19 +88,19 @@ public final class ConfigEntryTable
         BufferedReader in = null;
         try
         {
-            in = new BufferedReader(new InputStreamReader(new FileInputStream(file), ENCODING_LATIN1));
+            in = new BufferedReader(new InputStreamReader(new FileInputStream(file), ENCODING_UTF8));
             loadInitials(in);
             loadContents(in);
             in.close();
             in = null;
-            if (getValue(ConfigEntryType.ENCODING).equals(ENCODING_UTF8))
+            if (getValue(ConfigEntryType.ENCODING).equals(ENCODING_LATIN1))
             {
                 supported = true;
                 bookType = null;
                 questionable = false;
                 readahead = null;
                 table.clear();
-                in = new BufferedReader(new InputStreamReader(new FileInputStream(file), ENCODING_UTF8));
+                in = new BufferedReader(new InputStreamReader(new FileInputStream(file), ENCODING_LATIN1));
                 loadInitials(in);
                 loadContents(in);
                 in.close();
@@ -131,19 +132,19 @@ public final class ConfigEntryTable
         BufferedReader in = null;
         try
         {
-            in = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(buffer), ENCODING_LATIN1));
+            in = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(buffer), ENCODING_UTF8));
             loadInitials(in);
             loadContents(in);
             in.close();
             in = null;
-            if (getValue(ConfigEntryType.ENCODING).equals(ENCODING_UTF8))
+            if (getValue(ConfigEntryType.ENCODING).equals(ENCODING_LATIN1))
             {
                 supported = true;
                 bookType = null;
                 questionable = false;
                 readahead = null;
                 table.clear();
-                in = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(buffer), ENCODING_UTF8));
+                in = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(buffer), ENCODING_LATIN1));
                 loadInitials(in);
                 loadContents(in);
                 in.close();
@@ -223,7 +224,7 @@ public final class ConfigEntryTable
             }
             catch (IOException e)
             {
-                Reporter.informUser(this, Msg.UNLOCK_FAILED, e);
+                Reporter.informUser(this, UserMsg.UNLOCK_FAILED, e);
             }
         }
         return true;
@@ -286,7 +287,6 @@ public final class ConfigEntryTable
 
     /**
      * Sort the keys for a more meaningful presentation order.
-     * TODO(DM): Replace this with a conversion of the properties to XML and then by XSLT to HTML.
      */
     public Element toOSIS()
     {
@@ -367,15 +367,15 @@ public final class ConfigEntryTable
                 continue;
             }
 
-            int eqpos = line.indexOf('=');
-            if (eqpos == -1)
+            Matcher matcher = KEY_VALUE_PATTERN.matcher(line);
+            if (!matcher.matches())
             {
                 log.warn("Expected to see '=' in " + internal + ": " + line); //$NON-NLS-1$ //$NON-NLS-2$
                 continue;
             }
 
-            String key = line.substring(0, eqpos).trim();
-            String value = line.substring(eqpos + 1).trim();
+            String key = matcher.group(1).trim();
+            String value = matcher.group(2).trim();
             // Only CIPHER_KEYS that are empty are not ignored
             if (value.length() == 0 && !ConfigEntryType.CIPHER_KEY.getName().equals(key))
             {
@@ -386,11 +386,12 @@ public final class ConfigEntryTable
             // Create a configEntry so that the name is normalized.
             ConfigEntry configEntry = new ConfigEntry(internal, key);
 
-            ConfigEntry e = (ConfigEntry) table.get(configEntry.getType());
+            ConfigEntryType type = configEntry.getType();
+
+            ConfigEntry e = (ConfigEntry) table.get(type);
 
             if (e == null)
             {
-                ConfigEntryType type = configEntry.getType();
                 if (type == null)
                 {
                     log.warn("Ignoring unexpected entry in " + internal  + " of " + configEntry.getName()); //$NON-NLS-1$ //$NON-NLS-2$
@@ -401,7 +402,7 @@ public final class ConfigEntryTable
                 }
                 else
                 {
-                    table.put(configEntry.getType(), configEntry);
+                    table.put(type, configEntry);
                 }
             }
             else
@@ -416,7 +417,7 @@ public final class ConfigEntryTable
             // The config entry is History without the x.x.
             // We want to put x.x at the beginning of the string
             value = buf.toString();
-            if (ConfigEntryType.HISTORY.equals(configEntry.getType()))
+            if (ConfigEntryType.HISTORY.equals(type))
             {
                 int pos = key.indexOf('_');
                 value = key.substring(pos + 1) + ' ' + value;
@@ -440,7 +441,7 @@ public final class ConfigEntryTable
             if (line.charAt(0) == '[' && line.charAt(line.length() - 1) == ']')
             {
                 // The conf file contains a leading line of the form [KJV]
-                // This is the acronymn by which Sword refers to it.
+                // This is the acronym by which Sword refers to it.
                 initials = line.substring(1, line.length() - 1);
                 break;
             }
@@ -556,7 +557,7 @@ public final class ConfigEntryTable
      */
     private boolean isKeyLine(String line)
     {
-        return line.indexOf('=') != -1;
+        return KEY_VALUE_PATTERN.matcher(line).matches();
     }
 
     /**
@@ -578,19 +579,9 @@ public final class ConfigEntryTable
         }
         if (datapath.startsWith("./")) //$NON-NLS-1$
         {
-            add(ConfigEntryType.DATA_PATH, datapath.substring(2));
+            datapath = datapath.substring(2);
         }
-    }
-
-    private boolean isLeftToRight(String lang)
-    {
-        // Java does not know that the following languages are right to left
-        if ("fa".equals(lang) || "syr".equals(lang))  //$NON-NLS-1$ //$NON-NLS-2$
-        {
-            return false;
-        }
-
-        return ComponentOrientation.getOrientation(new Locale(lang)).isLeftToRight();
+        add(ConfigEntryType.DATA_PATH, datapath);
     }
 
     private void adjustLanguage()
@@ -599,49 +590,35 @@ public final class ConfigEntryTable
         String dir = (String) getValue(ConfigEntryType.DIRECTION);
         String newDir = dir == null ? (String) ConfigEntryType.DIRECTION.getDefault() : dir;
 
-        String langEntry = (String) getValue(ConfigEntryType.LANG);
-        String langFromEntry = (String) getValue(ConfigEntryType.GLOSSARY_FROM);
-        String langToEntry = (String) getValue(ConfigEntryType.GLOSSARY_TO);
-
-        // The LANG field should match the GLOSSARY_FROM field
-        if (langFromEntry != null && !langFromEntry.equals(langEntry))
+        Language lang = (Language) getValue(ConfigEntryType.LANG);
+        if (lang == null)
         {
-            langEntry = langFromEntry;
+            lang = Language.DEFAULT_LANG;
+            add(ConfigEntryType.LANG, lang.toString());
         }
+        testLanguage(internal, lang);
 
-        String lang = getLanguage(internal, langEntry);
-        add(ConfigEntryType.LANGUAGE, lang);
+        Language langFrom = (Language) getValue(ConfigEntryType.GLOSSARY_FROM);
+        Language langTo = (Language) getValue(ConfigEntryType.GLOSSARY_TO);
 
-        // This returns Left to Right if
-        // it does not know what it is.
-        boolean leftToRight = isLeftToRight(langEntry);
-
-        if (langFromEntry != null || langToEntry != null)
+        // If we have either langFrom or langTo, we are dealing with a glossary
+        if (langFrom != null || langTo != null)
         {
-            String langFrom = getLanguage(internal, langFromEntry);
-            add(ConfigEntryType.LANGUAGE_FROM, langFrom);
-            String langTo = getLanguage(internal, langToEntry);
-            add(ConfigEntryType.LANGUAGE_TO, langTo);
-            boolean fromLeftToRight = true;
-            boolean toLeftToRight = true;
-
-            if (langFromEntry == null)
+            if (langFrom == null)
             {
                 log.warn("Missing data for " + internal + ". Assuming " + ConfigEntryType.GLOSSARY_FROM.getName() + '=' + Languages.DEFAULT_LANG_CODE);  //$NON-NLS-1$ //$NON-NLS-2$
+                langFrom = Language.DEFAULT_LANG;
+                add(ConfigEntryType.GLOSSARY_FROM, lang.toString());
             }
-            else
-            {
-                fromLeftToRight = isLeftToRight(langFromEntry);
-            }
+            testLanguage(internal, langFrom);
 
-            if (langToEntry == null)
+            if (langTo == null)
             {
                 log.warn("Missing data for " + internal + ". Assuming " + ConfigEntryType.GLOSSARY_TO.getName() + '=' + Languages.DEFAULT_LANG_CODE);  //$NON-NLS-1$ //$NON-NLS-2$
+                langTo = Language.DEFAULT_LANG;
+                add(ConfigEntryType.GLOSSARY_TO, lang.toString());
             }
-            else
-            {
-                toLeftToRight = isLeftToRight(langToEntry);
-            }
+            testLanguage(internal, langTo);
 
             // At least one of the two languages should match the lang entry
             if (!langFrom.equals(lang) && !langTo.equals(lang))
@@ -652,11 +629,23 @@ public final class ConfigEntryTable
                           " match " + ConfigEntryType.LANG.getName()); //$NON-NLS-1$
             }
 
-            if (fromLeftToRight != toLeftToRight)
+            // The LANG field should match the GLOSSARY_FROM field
+            else if (!langFrom.equals(lang))
+            {
+            /*
+                log.error("Data error in " + internal + //$NON-NLS-1$
+                          ". " + ConfigEntryType.GLOSSARY_FROM.getName() + //$NON-NLS-1$
+                          " (" + langFrom.getCode() + ") does not match " + ConfigEntryType.LANG.getName() + " (" + lang.getCode() + ")"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
+             */
+                lang = langFrom;
+                add(ConfigEntryType.LANG, lang.toString());
+            }
+
+            if (langFrom.isLeftToRight() != langTo.isLeftToRight())
             {
                 newDir = ConfigEntryType.DIRECTION_BIDI;
             }
-            else if (fromLeftToRight)
+            else if (langFrom.isLeftToRight())
             {
                 newDir = ConfigEntryType.DIRECTION_LTOR;
             }
@@ -667,7 +656,7 @@ public final class ConfigEntryTable
         }
         else
         {
-            if (leftToRight)
+            if (lang.isLeftToRight())
             {
                 newDir = ConfigEntryType.DIRECTION_LTOR;
             }
@@ -706,7 +695,7 @@ public final class ConfigEntryTable
     {
         // The book type represents the underlying category of book.
         // Fine tune it here.
-        BookCategory focusedCategory = BookCategory.fromString(getValue(ConfigEntryType.CATEGORY).toString());
+        BookCategory focusedCategory = (BookCategory) getValue(ConfigEntryType.CATEGORY);
         questionable = focusedCategory == BookCategory.QUESTIONABLE;
 
         // From the config map, extract the important bean properties
@@ -740,7 +729,7 @@ public final class ConfigEntryTable
             focusedCategory = getBookType().getBookCategory();
         }
 
-        add(ConfigEntryType.CATEGORY, focusedCategory.toString());
+        add(ConfigEntryType.CATEGORY, focusedCategory.getName());
     }
 
     private void adjustName()
@@ -767,13 +756,12 @@ public final class ConfigEntryTable
 //        }
     }
 
-    private String getLanguage(String initials, String iso639Code)
+    private void testLanguage(String initials, Language lang)
     {
-        if (!Languages.isValidLanguage(iso639Code))
+        if (!lang.isValidLanguage())
         {
-            log.warn("Unknown language " + iso639Code + " in book " + initials); //$NON-NLS-1$ //$NON-NLS-2$
+            log.warn("Unknown language " + lang.getCode() + " in book " + initials); //$NON-NLS-1$ //$NON-NLS-2$
         }
-        return Languages.getLanguage(iso639Code);
     }
 
     /**
@@ -839,7 +827,6 @@ public final class ConfigEntryTable
         return buf.toString();
     }
 
-
    /**
      * Sword only recognizes two encodings for its modules: UTF-8 and LATIN1
      * Sword uses MS Windows cp1252 for Latin 1 not the standard. Arrgh!
@@ -872,15 +859,13 @@ public final class ConfigEntryTable
         ConfigEntryType.VERSION,
         ConfigEntryType.HISTORY,
         ConfigEntryType.OBSOLETES,
+        ConfigEntryType.INSTALL_SIZE,
     };
 
     private static final ConfigEntryType[] LANG_INFO =
     {
-        ConfigEntryType.LANGUAGE,
         ConfigEntryType.LANG,
-        ConfigEntryType.LANGUAGE_FROM,
         ConfigEntryType.GLOSSARY_FROM,
-        ConfigEntryType.LANGUAGE_TO,
         ConfigEntryType.GLOSSARY_TO,
     };
 
@@ -916,11 +901,15 @@ public final class ConfigEntryTable
         ConfigEntryType.MOD_DRV,
         ConfigEntryType.SOURCE_TYPE,
         ConfigEntryType.BLOCK_TYPE,
+        ConfigEntryType.BLOCK_COUNT,
         ConfigEntryType.COMPRESS_TYPE,
         ConfigEntryType.ENCODING,
         ConfigEntryType.MINIMUM_VERSION,
         ConfigEntryType.OSIS_VERSION,
+        ConfigEntryType.OSIS_Q_TO_TICK,
         ConfigEntryType.DIRECTION,
+        ConfigEntryType.KEY_TYPE,
+        ConfigEntryType.DISPLAY_LEVEL,
     };
 
     private static final ConfigEntryType[] HIDDEN =
@@ -969,4 +958,14 @@ public final class ConfigEntryTable
      * so that it can be updated.
      */
     private File configFile;
+
+    /**
+     * Pattern that matches a key=value.
+     * The key can contain ascii letters, numbers, underscore and period.
+     * The key must begin at the beginning of the line.
+     * The = sign following the key may be surrounded by whitespace.
+     * The value may contain anything, including an = sign.
+     */
+    private static final Pattern KEY_VALUE_PATTERN = Pattern.compile("^([A-Za-z0-9_.]+)\\s*=\\s*(.*)$"); //$NON-NLS-1$
+
 }
