@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: SwordUtil.java 1466 2007-07-02 02:48:09Z dmsmith $
+ * ID: $Id: SwordUtil.java 1887 2008-07-08 03:15:12Z dmsmith $
  */
 package org.crosswire.jsword.book.sword;
 
@@ -27,7 +27,6 @@ import java.io.UnsupportedEncodingException;
 
 import org.crosswire.common.util.Logger;
 import org.crosswire.jsword.book.DataPolice;
-import org.crosswire.jsword.passage.Key;
 
 /**
  * Various utilities used by different Sword classes.
@@ -39,7 +38,7 @@ import org.crosswire.jsword.passage.Key;
 public final class SwordUtil
 {
     /**
-     * Prevent Instansiation
+     * Prevent instantiation
      */
     private SwordUtil()
     {
@@ -152,9 +151,28 @@ public final class SwordUtil
         return byte4 | byte3 | byte2 | byte1;
     }
 
+    /**
+     * Encode little endian data from a byte array.
+     * This assumes that the number fits in a Java integer.
+     * That is, the range of an unsigned C integer is greater than a signed Java integer.
+     * For a practical limit, 2**31 is way bigger than any document that we can have.
+     * If this ever doesn't work, use a long for the number.
+     * 
+     * @param val the number to encode into little endian
+     * @param data the byte[] from which to write 4 bytes
+     * @param offset the offset into the array
+     */
+    protected static void encodeLittleEndian32(int val, byte[] data, int offset)
+    {
+        data[0 + offset] = (byte) (val & 0xFF);
+        data[1 + offset] = (byte) ((val >> 8) & 0xFF);
+        data[2 + offset] = (byte) ((val >> 16) & 0xFF);
+        data[3 + offset] = (byte) ((val >> 24) & 0xFF);
+    }
+
     /**
      * Decode little endian data from a byte array
-     * @param data the byte[] from which to read 4 bytes
+     * @param data the byte[] from which to read 2 bytes
      * @param offset the offset into the array
      * @return The decoded data
      */
@@ -168,6 +186,18 @@ public final class SwordUtil
         return byte2 | byte1;
     }
 
+    /**
+     * Encode a 16-bit little endian from an integer.
+     * It is assumed that the integer's lower 16 bits are the only that are set.
+     * @param data the byte[] from which to write 2 bytes
+     * @param offset the offset into the array
+     */
+    protected static void encodeLittleEndian16(int val, byte[] data, int offset)
+    {
+        data[0 + offset] = (byte) (val & 0xFF);
+        data[1 + offset] = (byte) ((val >> 8) & 0xFF);
+    }
+
     /**
      * Find a byte of data in an array
      * @param data The array to search
@@ -176,7 +206,19 @@ public final class SwordUtil
      */
     protected static int findByte(byte[] data, byte sought)
     {
-        for (int i = 0; i < data.length; i++)
+        return findByte(data, 0, sought);
+    }
+
+    /**
+     * Find a byte of data in an array
+     * @param data The array to search
+     * @param offset The position in the array to begin looking
+     * @param sought The data to search for
+     * @return The index of the found position or -1 if not found
+     */
+    protected static int findByte(byte[] data, int offset, byte sought)
+    {
+        for (int i = offset; i < data.length; i++)
         {
             if (data[i] == sought)
             {
@@ -190,23 +232,41 @@ public final class SwordUtil
     /**
      * Transform a byte array into a string given the encoding.
      * If the encoding is bad then it just does it as a string.
+     * 
      * @param data The byte array to be converted
      * @param charset The encoding of the byte array
      * @return a string that is UTF-8 internally
      */
-    public static String decode(Key key, byte[] data, String charset)
+    public static String decode(String key, byte[] data, String charset)
     {
-        return decode(key, data, data.length, charset);
+        return decode(key, data, 0, data.length, charset);
     }
 
     /**
-     * Transform a byte array into a string given the encoding.
+     * Transform a portion of a byte array into a string given the encoding.
      * If the encoding is bad then it just does it as a string.
+     * 
      * @param data The byte array to be converted
+     * @param length The number of bytes to use.
      * @param charset The encoding of the byte array
      * @return a string that is UTF-8 internally
      */
-    public static String decode(Key key, byte[] data, int length, String charset)
+    public static String decode(String key, byte[] data, int length, String charset)
+    {
+        return decode(key, data, 0, length, charset);
+    }
+
+    /**
+     * Transform a portion of a byte array starting at an offset into a string given the encoding.
+     * If the encoding is bad then it just does it as a string.
+     * 
+     * @param data The byte array to be converted
+     * @param offset The starting position in the byte array
+     * @param length The number of bytes to use.
+     * @param charset The encoding of the byte array
+     * @return a string that is UTF-8 internally
+     */
+    public static String decode(String key, byte[] data, int offset, int length, String charset)
     {
         if ("WINDOWS-1252".equals(charset)) //$NON-NLS-1$
         {
@@ -215,13 +275,13 @@ public final class SwordUtil
         String txt = ""; //$NON-NLS-1$
         try
         {
-            txt = new String(data, 0, length, charset);
+            txt = new String(data, offset, length, charset);
         }
         catch (UnsupportedEncodingException ex)
         {
             // It is impossible! In case, use system default...
             log.error(key + ": Encoding: " + charset + " not supported", ex); //$NON-NLS-1$ //$NON-NLS-2$
-            txt = new String(data, 0, length);
+            txt = new String(data, offset, length);
         }
 
         return txt;
@@ -233,7 +293,7 @@ public final class SwordUtil
      * and in UTF-8 or are non-printing control characters in the range
      * of 0-32.
      */
-    public static void clean1252(Key key, byte[] data)
+    public static void clean1252(String key, byte[] data)
     {
         clean1252(key, data, data.length);
     }
@@ -244,7 +304,7 @@ public final class SwordUtil
      * and in UTF-8 or are non-printing control characters in the range
      * of 0-32.
      */
-    public static void clean1252(Key key, byte[] data, int length)
+    public static void clean1252(String key, byte[] data, int length)
     {
         for (int i = 0; i < length; i++)
         {
@@ -255,7 +315,7 @@ public final class SwordUtil
                 || (c == 0x81 || c == 0x8D || c == 0x8F || c == 0x90 || c == 0x9D))
             {
                 data[i] = 0x20;
-                DataPolice.report(key.getName() + " has bad character 0x" + Integer.toString(c, 16) + " at position " + i + " in input."); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+                DataPolice.report(key + " has bad character 0x" + Integer.toString(c, 16) + " at position " + i + " in input."); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
             }
         }
     }
