@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: TreeKeyIndex.java 1466 2007-07-02 02:48:09Z dmsmith $
+ * ID: $Id: TreeKeyIndex.java 1794 2008-04-11 10:48:41Z dmsmith $
  */
 package org.crosswire.jsword.book.sword;
 
@@ -32,6 +32,7 @@ import org.crosswire.common.activate.Lock;
 import org.crosswire.common.util.FileUtil;
 import org.crosswire.common.util.Logger;
 import org.crosswire.common.util.NetUtil;
+import org.crosswire.common.util.Reporter;
 import org.crosswire.jsword.book.BookException;
 import org.crosswire.jsword.passage.DefaultKeyList;
 import org.crosswire.jsword.passage.Key;
@@ -52,25 +53,9 @@ public class TreeKeyIndex implements Activatable
      * Simple ctor
      * @throws BookException
      */
-    public TreeKeyIndex(SwordBookMetaData sbmd) throws BookException
+    public TreeKeyIndex(SwordBookMetaData sbmd)
     {
         bmd = sbmd;
-
-        String path = getExpandedDataPath();
-
-        idxFile = new File(path + EXTENSION_INDEX);
-        datFile = new File(path + EXTENSION_DATA);
-
-        if (!idxFile.canRead())
-        {
-            throw new BookException(Msg.READ_FAIL, new Object[] { idxFile.getAbsolutePath() });
-        }
-
-        if (!datFile.canRead())
-        {
-            throw new BookException(Msg.READ_FAIL, new Object[] { datFile.getAbsolutePath() });
-        }
-
     }
 
     /**
@@ -163,7 +148,7 @@ public class TreeKeyIndex implements Activatable
 
         Key key = new DefaultKeyList(null, bmd.getName());
         // Some of the keys have extraneous whitespace, so remove it.
-        node.setName(SwordUtil.decode(key, buffer, size, bmd.getBookCharset()).trim());
+        node.setName(SwordUtil.decode(key.getName(), buffer, size, bmd.getBookCharset()).trim());
 
         buffer = SwordUtil.readNextRAF(datRaf, 2);
         int userDataSize = SwordUtil.decodeLittleEndian16(buffer, 0);
@@ -180,6 +165,32 @@ public class TreeKeyIndex implements Activatable
      */
     public final void activate(Lock lock)
     {
+        String path = null;
+        try
+        {
+            path = getExpandedDataPath();
+        }
+        catch (BookException e)
+        {
+            Reporter.informUser(this, e);
+            return;
+        }
+
+        idxFile = new File(path + EXTENSION_INDEX);
+        datFile = new File(path + EXTENSION_DATA);
+
+        if (!idxFile.canRead())
+        {
+            Reporter.informUser(this, new BookException(UserMsg.READ_FAIL, new Object[] { idxFile.getAbsolutePath() }));
+            return;
+        }
+
+        if (!datFile.canRead())
+        {
+            Reporter.informUser(this, new BookException(UserMsg.READ_FAIL, new Object[] { datFile.getAbsolutePath() }));
+            return;
+        }
+
         try
         {
             idxRaf = new RandomAccessFile(idxFile, FileUtil.MODE_READ);
@@ -235,7 +246,7 @@ public class TreeKeyIndex implements Activatable
 
     private String getExpandedDataPath() throws BookException
     {
-        URI loc = NetUtil.lengthenURI(bmd.getLibrary(), bmd.getProperty(ConfigEntryType.DATA_PATH));
+        URI loc = NetUtil.lengthenURI(bmd.getLibrary(), (String) bmd.getProperty(ConfigEntryType.DATA_PATH));
 
         if (loc == null)
         {
