@@ -17,16 +17,17 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: LuceneIndexManager.java 1152 2006-10-10 23:30:55Z dmsmith $
+ * ID: $Id: LuceneIndexManager.java 1850 2008-05-10 18:34:02Z dmsmith $
  */
 package org.crosswire.jsword.index.lucene;
 
 import java.io.File;
 import java.io.IOException;
-import java.net.URL;
+import java.net.URI;
 import java.util.HashMap;
 import java.util.Map;
 
+import org.crosswire.common.util.CWProject;
 import org.crosswire.common.util.FileUtil;
 import org.crosswire.common.util.IOUtil;
 import org.crosswire.common.util.Logger;
@@ -38,11 +39,10 @@ import org.crosswire.jsword.book.BookMetaData;
 import org.crosswire.jsword.index.Index;
 import org.crosswire.jsword.index.IndexManager;
 import org.crosswire.jsword.index.IndexStatus;
-import org.crosswire.jsword.util.Project;
 
 /**
  * An implementation of IndexManager for Lucene indexes.
- * 
+ *
  * @see gnu.lgpl.License for license details.
  *      The copyright to this program is held by it's authors.
  * @author Joe Walker [joe at eireneh dot com]
@@ -56,9 +56,8 @@ public class LuceneIndexManager implements IndexManager
     {
         try
         {
-            URL storage = getStorageArea(book);
-            URL longer = NetUtil.lengthenURL(storage, DIR_SEGMENTS);
-            return NetUtil.isFile(longer);
+            URI storage = getStorageArea(book);
+            return NetUtil.isDirectory(storage);
         }
         catch (IOException ex)
         {
@@ -77,7 +76,7 @@ public class LuceneIndexManager implements IndexManager
             Index reply = (Index) INDEXES.get(book);
             if (reply == null)
             {
-                URL storage = getStorageArea(book);
+                URI storage = getStorageArea(book);
                 reply = new LuceneIndex(book, storage);
                 INDEXES.put(book, reply);
             }
@@ -86,7 +85,7 @@ public class LuceneIndexManager implements IndexManager
         }
         catch (IOException ex)
         {
-            throw new BookException(Msg.LUCENE_INIT, ex);
+            throw new BookException(UserMsg.LUCENE_INIT, ex);
         }
     }
 
@@ -102,10 +101,10 @@ public class LuceneIndexManager implements IndexManager
             public void run()
             {
                 IndexStatus finalStatus = IndexStatus.UNDONE;
-                URL storage = null;
+
                 try
                 {
-                    storage = getStorageArea(book);
+                    URI storage = getStorageArea(book);
                     Index index = new LuceneIndex(book, storage, true);
                     // We were successful if the directory exists.
                     if (NetUtil.getAsFile(storage).exists())
@@ -132,19 +131,19 @@ public class LuceneIndexManager implements IndexManager
     }
 
     /* (non-Javadoc)
-     * @see org.crosswire.jsword.index.search.IndexManager#installDownloadedIndex(org.crosswire.jsword.book.Book, java.net.URL)
+     * @see org.crosswire.jsword.index.search.IndexManager#installDownloadedIndex(org.crosswire.jsword.book.Book, java.net.URI)
      */
-    public void installDownloadedIndex(Book book, URL tempDest) throws BookException
+    public void installDownloadedIndex(Book book, URI tempDest) throws BookException
     {
         try
         {
-            URL storage = getStorageArea(book);
+            URI storage = getStorageArea(book);
             File zip = NetUtil.getAsFile(tempDest);
             IOUtil.unpackZip(zip, NetUtil.getAsFile(storage));
         }
         catch (IOException ex)
         {
-            throw new BookException(Msg.INSTALL_FAIL, ex);
+            throw new BookException(UserMsg.INSTALL_FAIL, ex);
         }
     }
 
@@ -170,7 +169,7 @@ public class LuceneIndexManager implements IndexManager
         }
         catch (IOException ex)
         {
-            throw new BookException(Msg.DELETE_FAILED, ex);
+            throw new BookException(UserMsg.DELETE_FAILED, ex);
         }
 
         FileUtil.delete(tempPath);
@@ -179,10 +178,10 @@ public class LuceneIndexManager implements IndexManager
     /**
      * Determine where an index should be stored
      * @param book The book to be indexed
-     * @return A URL to store stuff in
+     * @return A URI to store stuff in
      * @throws IOException If there is a problem in finding where to store stuff
      */
-    protected URL getStorageArea(Book book) throws IOException
+    protected URI getStorageArea(Book book) throws IOException
     {
         BookMetaData bmd = book.getBookMetaData();
         String driverName = bmd.getDriverName();
@@ -191,10 +190,10 @@ public class LuceneIndexManager implements IndexManager
         assert driverName != null;
         assert bookName != null;
 
-        URL base = Project.instance().getTempScratchSpace(DIR_LUCENE, false);
-        URL driver = NetUtil.lengthenURL(base, driverName);
+        URI base = CWProject.instance().getWriteableProjectSubdir(DIR_LUCENE, false);
+        URI driver = NetUtil.lengthenURI(base, driverName);
 
-        return NetUtil.lengthenURL(driver, bookName);
+        return NetUtil.lengthenURI(driver, bookName);
     }
 
     /**
@@ -202,12 +201,7 @@ public class LuceneIndexManager implements IndexManager
      */
     protected static final Map INDEXES = new HashMap();
 
-    /**
-     * The segments directory
-     */
-    private static final String DIR_SEGMENTS = "segments"; //$NON-NLS-1$
-
-    /**
+   /**
      * The lucene search index directory
      */
     private static final String DIR_LUCENE = "lucene"; //$NON-NLS-1$
