@@ -17,14 +17,14 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: QueryDecoratorFactory.java 1466 2007-07-02 02:48:09Z dmsmith $
+ * ID: $Id: QueryDecoratorFactory.java 1772 2008-03-08 02:37:36Z dmsmith $
  */
 package org.crosswire.jsword.index.query;
 
 import java.io.IOException;
 
-import org.crosswire.common.util.ClassUtil;
 import org.crosswire.common.util.Logger;
+import org.crosswire.common.util.PluginUtil;
 
 /**
  * A Factory class for QueryDecorator.
@@ -36,7 +36,7 @@ import org.crosswire.common.util.Logger;
 public final class QueryDecoratorFactory
 {
     /**
-     * Prevent Instansiation
+     * Prevent instantiation
      */
     private QueryDecoratorFactory()
     {
@@ -67,8 +67,7 @@ public final class QueryDecoratorFactory
     {
         try
         {
-            Class impl = ClassUtil.getImplementor(QueryDecorator.class);
-            instance = (QueryDecorator) impl.newInstance();
+            instance = (QueryDecorator) PluginUtil.getImplementation(QueryDecorator.class);
         }
         catch (IOException e)
         {
