@@ -17,7 +17,7 @@
  * Copyright: 2005
  *     The copyright to this program is held by it's authors.
  *
- * ID: $Id: PassageKeyFactory.java 1466 2007-07-02 02:48:09Z dmsmith $
+ * ID: $Id: PassageKeyFactory.java 1890 2008-07-09 12:15:15Z dmsmith $
  */
 package org.crosswire.jsword.passage;
 
@@ -103,20 +103,7 @@ public final class PassageKeyFactory implements KeyFactory
      */
     public Key getGlobalKeyList()
     {
-        try
-        {
-            if (whole == null)
-            {
-                whole = new ReadOnlyPassage(defaultType.createPassage("Gen 1:1-Rev 22:21"), true); //$NON-NLS-1$
-            }
-
-            return whole;
-        }
-        catch (NoSuchKeyException ex)
-        {
-            assert false : ex;
-            return defaultType.createEmptyPassage();
-        }
+        return whole;
     }
 
     /**
@@ -576,6 +563,11 @@ public final class PassageKeyFactory implements KeyFactory
         return buf.toString();
     }
 
+    /**
+     * The default type
+     */
+    private static PassageType defaultType = PassageType.SPEED;
+
     /**
      * How we create Passages
      */
@@ -586,8 +578,16 @@ public final class PassageKeyFactory implements KeyFactory
      */
     private static Passage whole;
 
-    /**
-     * The default type
-     */
-    private static PassageType defaultType = PassageType.SPEED;
+    static
+    {
+        try
+        {
+            whole = new ReadOnlyPassage(defaultType.createPassage("Gen 1:1-Rev 22:21"), true); //$NON-NLS-1$
+        }
+        catch (NoSuchKeyException ex)
+        {
+            assert false : ex;
+            whole = defaultType.createEmptyPassage();
+        }
+    }
 }
